<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Widget_Kath_Blog extends Widget_Base {

   public function get_name() {
   return 'kath-blog';
   }

   public function get_title() {
      return __( 'Kath Blog', 'kath-custom-elements' );
   }

   public function get_icon() {
      // Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
      return 'eicon-post-list';
   }

   public function get_categories() {
      return [ 'kath-custom-elements' ];
   }

   protected function _register_controls() {

      $this->start_controls_section(
         'kath_section_blog',
         [
            'label' => __( 'Kath Blog Settings', 'kath-custom-elements' )
         ]
      );

      $this->add_control(
         'post_type',
         [
            'label' => __( 'Select Posts Type', 'kath-custom-elements' ),
            'type' => Controls_Manager::SELECT,
            'default' => 'latest',
            'options' => [
               'latest' => __( 'Latest', 'kath-custom-elements' ),
               'category' => __( 'Category', 'kath-custom-elements' ),
            ]
         ]
      );

      $this->add_control(
         'category',
         [
         'label' => __( 'Categories', 'kath-custom-elements' ),
         'type' => Controls_Manager::SELECT,
         'label_block' => true,
         'options' => kath_post_type_categories('testi_cat'),
         'condition' => [
            'post_type' => 'category'
          ]
         ]
      );

      $this->add_control(
         'posts_per_page',
         [
            'label' => __( 'Posts Per page', 'kath-custom-elements' ),
            'type' => Controls_Manager::NUMBER,
            'default' => '4',
            'title' => __( 'Enter Posts Per Page', 'kath-custom-elements' ),
         ]
      );

      $this->add_control(
         'posts_offset',
         [
            'label' => __( 'Posts Offset', 'kath-custom-elements' ),
            'type' => Controls_Manager::NUMBER,
            'default' => '0',
            'title' => __( 'Enter Offset Value', 'kath-custom-elements' ),
         ]
      );  

        $this->add_control(
            'post_order',
            [
                'label' => __( 'Order', 'kath-custom-elements' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' => __( 'Ascending', 'kath-custom-elements' ),
                    'desc' => __( 'Descending', 'kath-custom-elements' )
                ],
                'default' => 'desc',
            ]
        ); 

        $this->add_control(
            'blog_layout',
            [
                'label' => __( 'Layout', 'kath-custom-elements' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout1' => __( 'Layout1', 'kath-custom-elements' ),
                    'layout2' => __( 'Layout2', 'kath-custom-elements' )
                ],
                'default' => 'layout1',
            ]
        ); 

        $this->add_control(
            'column_no',
            [
                'label' => __( 'No of column', 'kath-custom-elements' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => __( '1', 'kath-custom-elements' ),
                    '2' => __( '2', 'kath-custom-elements' ),
                    '3' => __( '3', 'kath-custom-elements' ),
                    '4' => __( '4', 'kath-custom-elements' ),
                ],
                'default' => '3',
                'condition'     => [
                        'blog_layout' => 'layout1'
                    ]
            ]
        );  

      $this->end_controls_section();
      
      //Content Settings
      $this->start_controls_section(
         'kath_blog_contents',
         [
            'label' => __( 'Content Settings', 'kath-custom-elements' )
         ]
      );

      $this->add_control(
          'show_content',
          [
            'label' => esc_html__( 'Show Content', 'kath-custom-elements' ),
            'type' => Controls_Manager::SWITCHER,
            'default' => 'true',
            'return_value' => 'true',
            'condition' => ['blog_layout'=>'layout1']
          ]
      );

      $this->add_control(
         'excerpt_length',
         [
            'label' => __( 'Excerpt Length', 'kath-custom-elements' ),
            'type' => Controls_Manager::NUMBER,
            'default' => '30',
            'title' => __( 'Enter Excerpt Value', 'kath-custom-elements' ),
         ]
      ); 

      $this->add_control(
         'readmore_text',
         [
            'label' => __( 'Read More Text', 'kath-custom-elements' ),
            'type' => Controls_Manager::TEXT,
            'default' => 'Read Full Story',
         ]
      ); 

      $this->end_controls_section(); 
      
      //Styles
      $this->start_controls_section(
         'kath_post_style',
         [
            'label' => __( 'Colors & Typography', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE
         ]
      );

      $this->add_control(
         'kath_title_color',
         [
            'label' => __( 'Post Title Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
               '{{WRAPPER}} .yeti-blog h5 a' => 'color: {{VALUE}}',
            ]

         ]
      );
      $this->add_control(
         'kath_title_hcolor',
         [
            'label' => __( 'Hover Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
               '{{WRAPPER}} .yeti-blog h5 a:hover' => 'color: {{VALUE}}',
            ]

         ]
      );

      $this->add_group_control(
         Group_Control_Typography::get_type(),
         [
            'name' => 'kath_title_typo',
            'label' => esc_html__( 'Title Typography', 'kath-custom-elements' ),
            'selector' => '{{WRAPPER}} .yeti-blog h5',
         ]
      );


      $this->end_controls_section();
   }

    protected function render( ) {

		// get our input from the widget settings.
		$settings = $this->get_settings();
    
    $layout = $settings['blog_layout'];
    $column = $settings['column_no'];
    $col = 12/$column;
    $readmore_text = $settings['readmore_text'];
    $excerpt_length = $settings['excerpt_length'];

		$post_type = $settings['post_type'];
		$per_page = $settings['posts_per_page'];
		$offset = $settings['posts_offset'];
		$order = $settings['post_order'];
		$cat_id = $settings['category'];
    $show_content = $settings['show_content'];

        $args = array(
        	'post_type'         => 'post',
        	'posts_per_page'    => $per_page,
        	'offset'            => $offset,
        	'order'             => $order,
        	'orderby'           => 'ID',
        );
        if( $post_type == 'category' ){
        	$args['tax_query'] = array(
                array(
                    'taxonomy' => 'category',
                    'field' => 'term_id',
                    'terms'    => explode(',',$cat_id)
                ),
        		);
        }

        $posts = new \WP_Query( $args );
        if( $posts->have_posts() ):
		    ?>
			<div class="row yeti-blog">
                <?php
                $count = 0; 
                $odd = 0;
                $bg = 2;
                while( $posts->have_posts() ): $posts->the_post();
                    $count++;
                    $class = '';
                    if($layout == 'layout1'):
                      if(!has_post_thumbnail()){
                        $class = 'no-image';
                      }
                      ?>
                      <div class="col-md-<?php echo (int)$col;?> col-sm-<?php echo (int)$col;?> col-xs-<?php echo (int)$col;?> <?php echo esc_attr($class);?>" >
                        <figure>
                          <a href="<?php the_permalink();?>">
                            <img src="<?php the_post_thumbnail_url('yeti-blog-el2');?>" alt="<?php the_title_attribute();?>">
                          </a>
                          <figcaption>
                            <?php the_category();?>
                          </figcaption>
                        </figure>
                        <?php 
                        if(!has_post_thumbnail()){
                          the_category();
                        }
                        ?>
                        <h4>
                          <a href="<?php the_permalink();?>"><?php the_title();?></a>
                        </h4>
                        <?php 
                         if(defined('YETI_THEME')){
                          yeti_entry_meta();
                         }
                        ?>

                        <?php if($show_content == 'true'):?>
                        <div class="dis">
                          <p>
                          <?php 
                            $content = strip_shortcodes( strip_tags(get_the_content()));
                            echo wp_trim_words($content,$excerpt_length,'...');
                          ?>
                          </p>
                        </div>
                        <?php if($readmore_text!=''){?>
                        <a href="<?php the_permalink();?>" class="link"><?php echo esc_html($readmore_text);?> <i class="fa fa-long-arrow-right"></i></a>
                        <?php } endif;?>
                      </div>
                      <?php
                    else:  
                      if($count%2!=0){
                      	$odd++;
                      	if($odd%2==0){
                      		$class = 'float-right';
                      		$float = 'right';
                      	}else{
                      		$class = '';
                      		$float = 'left';
                      	}
  	                    ?>
  	                    <div class="col-md-8 col-sm-12 col-xs-12 <?php echo esc_attr($class);?>">
  	                        <div class="fixed">
  	                            <a href="<?php the_permalink();?>">
  	                                <img src="<?php the_post_thumbnail_url('yeti-blog-el1');?>" alt="<?php the_title_attribute();?>">
  	                            </a>
  	                            <div class="figure-text <?php echo esc_attr($float);?>">
  	                                <h4>
  	                                    <a href="<?php the_permalink();?>"><?php the_title();?></a>
  	                                </h4>
  	                                <div class="dis"><p>
                                    <?php
                                    $content = strip_shortcodes( strip_tags(get_the_content())); 
                                    echo wp_trim_words($content,$excerpt_length,'...');
                                    ?>
                                    </p></div>
                                    <?php if($readmore_text!=''){?>
  	                                <a class="link" href="<?php the_permalink();?>"><?php echo esc_html($readmore_text);?> <i class="fa fa-long-arrow-right"></i></a>
  	                                <?php }?>
                                </div>
  	                        </div>
  	                    </div>
  	                    <?php 
                      }
                      else{ 
                      	$bg = $bg+3; ?>
  	                    <div class="col-md-4 col-sm-12 col-xs-12">
  	                        <div class="fixed side-text bg<?php echo esc_attr($bg);?>">
  	                            <i class="fa fa-quote-left"></i>
  	                            <h4><a href="<?php the_permalink();?>"><?php the_title();?></a></h4>
                                <?php if($readmore_text!=''){?>
                                <a class="link" href="<?php the_permalink();?>"><?php echo esc_html($readmore_text);?> <i class="fa fa-long-arrow-right"></i></a>
                                <?php }?>
  	                        </div>
  	                    </div>
  	                    <?php
                      }
                    endif;
                endwhile;
                wp_reset_postdata();
                ?>
            </div>
            <?php
        endif;    
    }

   protected function content_template() {}

   public function render_plain_content( $instance = [] ) {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Widget_Kath_Blog() );