<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Widget_Kath_Button extends Widget_Base {

   public function get_name() {
      return 'kath-button';
   }

   public function get_title() {
      return esc_html__( 'Kath Button', 'kath-custom-elements' );
   }

   public function get_icon() {
      // Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
      return 'eicon-button';
   }
   public function get_categories() {
      return [ 'kath-custom-elements' ];
   }

   protected function _register_controls() {

		$this->start_controls_section(
		 'kath_section_button',
		 [
		    'label' => esc_html__( 'Button Settings', 'kath-custom-elements' )
		 ]
		);

		$this->add_control(
		     'button_text',
		     [
		        'label' => esc_html__( 'Button Text', 'kath-custom-elements' ),
		        'type' => Controls_Manager::TEXT,
		     ]
		);

		$this->add_control(
			'button_link',
			[
				'label'             => __( 'Button Link', 'kath-custom-elements' ),
				'type'              => Controls_Manager::URL,
				'dynamic'           => [
					'active'  => true,
				],
				'label_block'       => false,
				'placeholder'       => __( 'http://your-link.com', 'kath-custom-elements' ),
			]
		);
      $this->add_control(
         'button_layout',
         [
             'label' => __( 'Layout', 'kath-custom-elements' ),
             'type' => Controls_Manager::SELECT,
             'options' => [
                 'layout1' => __( 'Layout1', 'kath-custom-elements' ),
                 'layout2' => __( 'Layout2', 'kath-custom-elements' )
             ],
             'default' => 'layout1',
         ]
      ); 
      $this->end_controls_section();

      $this->start_controls_section(
         'button_styles',
         [
            'label' => esc_html__( 'Typography', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE
         ]
      );

      $this->add_group_control(
         Group_Control_Typography::get_type(),
         [
            'name' => 'button_title_typo',
            'label' => esc_html__( 'Title Typography', 'kath-custom-elements' ),
            'selector' => '{{WRAPPER}} a, {{WRAPPER}} a.link .text',
         ]
      );

      $this->end_controls_section(); 

      $this->start_controls_section(
         'kath_button_style',
         [
            'label' => esc_html__( 'Buttons Style', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE
         ]
      );

    $this->add_responsive_control(
      'kath_button_alignment',
      [
        'label' => __( 'Button Alignment', 'kath-custom-elements' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          'left' => [
            'title' => __( 'Left', 'kath-custom-elements' ),
            'icon' => 'fa fa-align-left',
          ],
          'center' => [
            'title' => __( 'Center', 'kath-custom-elements' ),
            'icon' => 'fa fa-align-center',
          ],
          'right' => [
            'title' => __( 'Right', 'kath-custom-elements' ),
            'icon' => 'fa fa-align-right',
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .yeti-button' => 'text-align: {{VALUE}};',
        ]
      ]
    );

      $this->start_controls_tabs( 'tabs_button_style' );

      $this->start_controls_tab(
         'tab_button_normal',
         [
            'label' => esc_html__( 'Normal', 'kath-custom-elements' ),
         ]
      );

      $this->add_control(
         'button_text_color',
         [
            'label' => esc_html__( 'Text Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default'=> '#fff',
            'selectors' => [
               '{{WRAPPER}} a' => 'color: {{VALUE}};',
            ],
         ]
      );

      $this->add_control(
         'background_color',
         [
            'label' => esc_html__( 'Background Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default'=> '#ef6936',
            'scheme' => [
               'type' => Scheme_Color::get_type(),
               'value' => Scheme_Color::COLOR_4,
            ],
            'selectors' => [
               '{{WRAPPER}} a.btn-effect, {{WRAPPER}} .link span.text:after, {{WRAPPER}} .link .btn-up:after, {{WRAPPER}} .link .btn-up:before' => 'background-color: {{VALUE}};',
            ],
         ]
      );

      $this->add_group_control(
         Group_Control_Border::get_type(), 
            [
               'name'          => 'button_border_normal',
               'selector'      => '{{WRAPPER}} a',
            ]
      );

      $this->end_controls_tab();

      $this->start_controls_tab(
         'tab_button_hover',
         [
            'label' => esc_html__( 'Hover', 'kath-custom-elements' ),
         ]
      );

      $this->add_control(
         'button_text_hover_color',
         [
            'label' => esc_html__( 'Text Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default'=>'#fff',
            'selectors' => [
               '{{WRAPPER}} a:hover' => 'color: {{VALUE}};',
            ],
         ]
      );

      $this->add_control(
         'button_background_hover_color',
         [
            'label' => esc_html__( 'Background Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default'=> '#5031a9',
            'selectors' => [
               '{{WRAPPER}} a.btn-effect:hover, {{WRAPPER}} .link:hover span.text:after, {{WRAPPER}} a.link.animate:hover .btn-up:before, {{WRAPPER}} a.link.animate:hover .btn-up:after' => 'background-color: {{VALUE}};',
            ],
         ]
      );

      $this->add_group_control(
         Group_Control_Border::get_type(), 
            [
               'name'          => 'button_border_hover',
               'selector'      => '{{WRAPPER}} a:hover',
            ]
      );

      $this->end_controls_tab();

     /*Button Padding*/
      $this->add_responsive_control('button_padding',
         [
            'label'         => esc_html__('Padding', 'kath-custom-elements'),
            'type'          => Controls_Manager::DIMENSIONS,
            'size_units'    => ['px', 'em', '%'],
            'selectors'     => [
               '{{WRAPPER}} a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
            ]
         ]
      );

      $this->end_controls_tabs();    

   }

   protected function render( ) {

	    // get our input from the widget settings.
	    $settings = $this->get_settings();
        $layout = ! empty( $settings['button_layout'] ) ? $settings['button_layout'] : 'layout1';
        $button_text = ! empty( $settings['button_text'] ) ? $settings['button_text'] : '';
        $button_key = $settings['button_link'];
        $button_link = $button_key['url'];
        $external = $button_key['is_external'];
        $nofollow = $button_key['nofollow'];
        
        if($layout == 'layout1'){
        ?>
        <div class="yeti-button">
     			<a class="text-capitalize btn-effect" href="<?php echo esc_url($button_link);?>" <?php if(!empty($external)){?>target="_blank"<?php }?> <?php if(!empty($nofollow)){?>rel="nofollow"<?php }?>>
     				<span><?php echo esc_html($button_text);?></span>
     			</a>
        </div>
        <?php
        }else{
         ?>
         <div class="yeti-button">
             <a href="<?php echo esc_url($button_link);?>" class="link animate" <?php if(!empty($external)){?>target="_blank"<?php }?> <?php if(!empty($nofollow)){?>rel="nofollow"<?php }?>>
                <span class="text"><?php echo esc_html($button_text);?></span>
                <span class="bdr btn-up"></span>
             </a>
         </div>
         <?php
        }
        

   }

   protected function content_template() {}

   public function render_plain_content( $instance = [] ) {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Widget_Kath_Button() );

