<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Widget_Case_Studies extends Widget_Base {

   public function get_title() {
      return esc_html__( 'Case Study', 'kath-custom-elements' );
   }

   public function get_icon() {
      return 'eicon-image-box';
   }
   public function get_categories() {
      return [ 'kath-custom-elements' ];
   }
   public function get_name() {
   return 'case-study';
   }
   protected function _register_controls() {

		$this->start_controls_section(
		 'case_study_setting',
		 [
		    'label' => esc_html__( 'Main Settings', 'kath-custom-elements' )
		 ]
		);

		$this->add_control(
			'case_study_image',
			[
				'label' => __( 'Choose Image', 'elementor' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' => 'case_study_image', 
				'default' => 'large',
				'separator' => 'none',
			]
		);

		$this->add_control(
		     'case_study_project',
		     [
		        'label' => esc_html__( 'Service Provided', 'kath-custom-elements' ),
		        'type' => Controls_Manager::TEXT,
		     ]
		);

		$this->add_control(
		     'case_study_company',
		     [
		        'label' => esc_html__( 'Company Name', 'kath-custom-elements' ),
		        'type' => Controls_Manager::TEXT,
		     ]
		); 

		$this->add_control(
		     'case_study_button_text',
		     [
		        'label' => esc_html__( 'Button Text', 'kath-custom-elements' ),
		        'type' => Controls_Manager::TEXT,
		     ]
		);

		$this->add_control(
		     'case_study_button_url',
		     [
		        'label' => esc_html__( 'Button URL', 'kath-custom-elements' ),
		        'type' => Controls_Manager::TEXT,
		     ]
		);

      $this->end_controls_section();

      $this->start_controls_section(
         'pname_styles',
         [
            'label' => esc_html__( 'Title Styles', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE
         ]
      );

      $this->add_control(
         'pname_style',
         [
            'label' => esc_html__( 'Project Name', 'kath-custom-elements' ),
            'type' => Controls_Manager::HEADING,
            'separator' => 'before',
         ]
      );

      $this->add_group_control(
         Group_Control_Typography::get_type(),
         [
            'name' => 'pname_typo',
            'label' => esc_html__( 'Typography', 'kath-custom-elements' ),
            'selector' => '{{WRAPPER}} .case-title h4',
         ]
      );

      $this->add_control(
         'pname_color',
         [
            'label' => esc_html__( 'Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default' => '#fff',
            'selectors' => [
               '{{WRAPPER}} .case-title h4' => 'color: {{VALUE}}',
            ]

         ]
      );

      $this->add_control(
         'cname_style',
         [
            'label' => esc_html__( 'Company Name', 'kath-custom-elements' ),
            'type' => Controls_Manager::HEADING,
            'separator' => 'before',
         ]
      );

      $this->add_group_control(
         Group_Control_Typography::get_type(),
         [
            'name' => 'cname_typo',
            'label' => esc_html__( 'Typography', 'kath-custom-elements' ),
            'selector' => '{{WRAPPER}} .case-title small',
         ]
      );

      $this->add_control(
         'cname_color',
         [
            'label' => esc_html__( 'Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default' => '#fff',
            'selectors' => [
               '{{WRAPPER}} .case-title small' => 'color: {{VALUE}}',
            ]

         ]
      );


      $this->end_controls_section(); 

      $this->start_controls_section(
         'case_study_button_style',
         [
            'label' => esc_html__( 'Button Style', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE
         ]
      );

      $this->add_control(
         'button_text_color',
         [
            'label' => esc_html__( 'Text Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default'=> '#fff',
            'selectors' => [
               '{{WRAPPER}} .link .text' => 'color: {{VALUE}};',
               '{{WRAPPER}} .link span:after' => 'background-color: {{VALUE}};',
            ],
         ]
      );

      $this->add_control(
         'button_border_color',
         [
            'label' => esc_html__( 'Hover Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default'=> '#ef6936',
            'selectors' => [
               '{{WRAPPER}} .link:hover span:after, {{WRAPPER}} .link:hover span:before' => 'background-color: {{VALUE}};',
            ],
         ]
      );

      $this->end_controls_section();  

      $this->start_controls_section(
         'case_study_overlay_style',
         [
            'label' => esc_html__( 'Overlay Style', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE
         ]
      );

      $this->add_control(
         'overlay_color',
         [
            'label' => esc_html__( 'Overlay Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default'=> 'rgba(80,49,169,0.7)',
            'selectors' => [
               '{{WRAPPER}} .case-study .overlay' => 'background-color: {{VALUE}};',
            ],
         ]
      );

      $this->end_controls_section();  


   }

   protected function render( ) {

	    // get our input from the widget settings.
	    $settings = $this->get_settings();

         $case_image = ! empty( $settings['case_study_image'] ) ? $settings['case_study_image'] : '';
         $case_image_url = Group_Control_Image_Size::get_attachment_image_src( $case_image['id'], 'case_study_image', $settings );  
         if( empty( $case_image_url ) ) : $case_image_url = $case_image['url']; else: $case_image_url = $case_image_url; endif;

         ?>
        <div class="case-study">
            <figure>
                <img src="<?php echo esc_url($case_image_url);?>" alt="<?php echo esc_attr__('case_image','kath-custom-elements');?>">
                <span class="overlay"></span>
            </figure>
            <div class="case-title text-center">
                <h4>
                    <small><?php echo esc_html($settings['case_study_project'])?></small>
                    <?php echo esc_html($settings['case_study_company'])?>
                </h4>
                <?php if($settings['case_study_button_text']!=''){?>
                <a href="<?php echo esc_html($settings['case_study_button_url']);?>" class="link view animate">
                    <span class="text"><?php echo esc_html($settings['case_study_button_text']);?></span>
                    <span class="bdr btn-up"></span>
                </a>
                <?php }?>
            </div>
        </div>

      <?php

   }

   protected function content_template() {}

   public function render_plain_content( $instance = [] ) {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Widget_Case_Studies() );

