<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Widget_Kath_Portfolio extends Widget_Base {

   public function get_name() {
   return 'kath-portfolio';
   }

   public function get_title() {
      return __( 'Kath Portfolio', 'kath-custom-elements' );
   }

   public function get_icon() {
      // Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
      return 'eicon-gallery-grid';
   }
   public function get_categories() {
      return [ 'kath-custom-elements' ];
   }

   protected function _register_controls() {

      $this->start_controls_section(
         'kath_section_portfolio',
         [
            'label' => __( 'Kath Portfolio Settings', 'kath-custom-elements' )
         ]
      );

      $this->add_control(
         'post_type',
         [
            'label' => __( 'Select Posts Type', 'kath-custom-elements' ),
            'type' => Controls_Manager::SELECT,
            'default' => 'latest',
            'options' => [
               'latest' => __( 'Latest', 'kath-custom-elements' ),
               'category' => __( 'Category', 'kath-custom-elements' ),
            ]
         ]
      );

      $this->add_control(
         'category',
         [
         'label' => __( 'Categories', 'kath-custom-elements' ),
         'type' => Controls_Manager::SELECT,
         'label_block' => true,
         'options' => kath_post_type_categories('portfolio_cat'),
         'condition' => [
            'post_type' => 'category'
          ]
         ]
      );

      $this->add_control(
         'posts_per_page',
         [
            'label' => __( 'Posts Per page', 'kath-custom-elements' ),
            'type' => Controls_Manager::NUMBER,
            'default' => '4',
            'title' => __( 'Enter Posts Per Page', 'kath-custom-elements' ),
         ]
      );

      $this->add_control(
         'posts_offset',
         [
            'label' => __( 'Posts Offset', 'kath-custom-elements' ),
            'type' => Controls_Manager::NUMBER,
            'default' => '0',
            'title' => __( 'Enter Offset Value', 'kath-custom-elements' ),
         ]
      );  

        $this->add_control(
            'post_order',
            [
                'label' => __( 'Order', 'kath-custom-elements' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' => __( 'Ascending', 'kath-custom-elements' ),
                    'desc' => __( 'Descending', 'kath-custom-elements' )
                ],
                'default' => 'desc',
            ]
        ); 

        $this->add_control(
            'portfolio_layout',
            [
                'label' => __( 'Layout', 'kath-custom-elements' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout1' => __( 'Layout1', 'kath-custom-elements' ),
                    'layout2' => __( 'Layout2', 'kath-custom-elements' ),
                    'layout3' => __( 'Layout3', 'kath-custom-elements' ),
                ],
                'default' => 'layout1',
            ]
        );    

      $this->end_controls_section();

      //Slider Settings
      $this->start_controls_section(
           'kath_section_portfolio_slider',
           [
              'label' => __( 'Slider Settings', 'kath-custom-elements' ),
              'condition' => ['portfolio_layout' => 'layout3']
           ]
      );

        $this->add_control(
           'show_items',
           [
              'label' => __( 'Items to show', 'kath-custom-elements' ),
              'type' => Controls_Manager::NUMBER,
              'default' => '4',
           ]
        ); 

        $this->add_control(
           'scroll_items',
           [
              'label' => __( 'Items to scroll', 'kath-custom-elements' ),
              'type' => Controls_Manager::NUMBER,
              'default' => '1',
           ]
        ); 

      $this->add_control('auto_play',
          [
              'label'         => esc_html__('Auto Play', 'kath-custom-elements'),
              'type'          => Controls_Manager::SWITCHER,
          ]
      );

      $this->add_control('show_arrow',
          [
              'label'         => esc_html__('Show Arrow', 'kath-custom-elements'),
              'type'          => Controls_Manager::SWITCHER,
          ]
      );

      $this->add_control('show_dots',
          [
              'label'         => esc_html__('Show Dots', 'kath-custom-elements'),
              'type'          => Controls_Manager::SWITCHER,
              'default'       => 'yes'
          ]
      );    

      $this->end_controls_section();

      $this->start_controls_section(
         'kath_portfolio_style',
         [
            'label' => __( 'Colors & Typography', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE
         ]
      );

      $this->add_control(
           'portfolio_title_style',
           [
              'label' => esc_html__( 'Title Styles', 'kath-custom-elements' ),
              'type' => Controls_Manager::HEADING,
              'separator' => 'before',
           ]
      ); 

      $this->add_control(
         'kath_title_color',
         [
            'label' => __( 'Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
               '{{WRAPPER}} .portfolio-wrap h4 a' => 'color: {{VALUE}}',
            ]

         ]
      );

      $this->add_group_control(
         Group_Control_Typography::get_type(),
         [
            'name' => 'kath_title_typo',
            'label' => esc_html__( 'Typography', 'kath-custom-elements' ),
            'selector' => '{{WRAPPER}} .portfolio-wrap h4 a',
         ]
      );

      $this->add_control(
           'portfolio_subtitle_style',
           [
              'label' => esc_html__( 'Sub Title Styles', 'kath-custom-elements' ),
              'type' => Controls_Manager::HEADING,
              'separator' => 'before',
           ]
      ); 

      $this->add_control(
         'kath_subtitle_color',
         [
            'label' => __( 'Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
               '{{WRAPPER}} .portfolio-wrap .sub-title' => 'color: {{VALUE}}',
            ]

         ]
      );

      $this->add_group_control(
         Group_Control_Typography::get_type(),
         [
            'name' => 'kath_subtitle_typo',
            'label' => esc_html__( 'Typography', 'kath-custom-elements' ),
            'selector' => '{{WRAPPER}} .portfolio-wrap .sub-title',
         ]
      );


      $this->end_controls_section();
   }

    protected function render( ) {

		// get our input from the widget settings.
		$settings = $this->get_settings();

        //Slider Settings
        $auto_play = $settings['auto_play'];
        if($auto_play == 'yes'){
          $auto_play = 'true';
        }else{
          $auto_play = 'false';
        }
        $show_arrow = $settings['show_arrow'];
        if($show_arrow == 'yes'){
          $show_arrow = 'true';
        }else{
          $show_arrow = 'false';
        }
        $show_dots = $settings['show_dots'];
        if($show_dots == 'yes'){
          $show_dots = 'true';
        }else{
          $show_dots = 'false';
        }

        $slider_options = [
            'autoplay' => $auto_play,
            'dots' => $show_dots,
            'arrows' => $show_arrow,
            'items' => $settings['show_items'],
            'scroll' => $settings['scroll_items'],
        ];

    $layout = $settings['portfolio_layout'];
		$post_type = $settings['post_type'];
		$per_page = $settings['posts_per_page'];
		$offset = $settings['posts_offset'];
		$order = $settings['post_order'];
		$cat_id = $settings['category'];

        $args = array(
        	'post_type'         => 'yeti_portfolio',
        	'posts_per_page'    => $per_page,
        	'offset'            => $offset,
        	'order'             => $order,
        	'orderby'           => 'ID',
        );
        if( $post_type == 'category' ){
        	$args['tax_query'] = array(
                array(
                    'taxonomy' => 'portfolio_cat',
                    'field' => 'term_id',
                    'terms'    => explode(',',$cat_id)
                ),
        		);
        }

        $posts = new \WP_Query( $args );
        if( $posts->have_posts() ):
        if($layout == 'layout3'){
          ?>
          <div class="portfolio-slider" data-settings='<?php echo wp_json_encode($slider_options); ?>'>
            <?php
            while( $posts->have_posts() ): $posts->the_post();
                $meta = get_post_meta(get_the_ID(),'yeti_portfolio_option',true);
                $company = isset($meta['company']) ? $meta['company'] : '';
                $image_size = 'yeti-portfolio-slider';
                ?>
                <div class="our-work">
                    <figure>
                      <a href="<?php the_post_thumbnail_url('full');?>" data-lightbox="image-1" data-title="<?php the_title();?>">
                        <img src="<?php the_post_thumbnail_url($image_size);?>" alt="<?php the_title_attribute();?>">
                        <?php if($layout == 'layout2'){?>
                        <div class="overlay"></div>
                        <?php }?>
                      </a>
                    </figure>
                </div>
                <?php
            endwhile;
            wp_reset_postdata();
            ?>
          </div>
          <?php
        } else{ 
		    ?>
			<div class="container-fluid nopad port-<?php echo esc_attr($layout);?>">
                <?php
                $count = 0; 
                $bg = 9;
                while( $posts->have_posts() ): $posts->the_post();
                    $total = $posts->post_count();
                    $count++;
                    $bg++;
                  	$meta = get_post_meta(get_the_ID(),'yeti_portfolio_option',true);
                  	$company = isset($meta['company']) ? $meta['company'] : '';
                    $image_size = 'yeti-portfolio-el';
                    if($layout == 'layout1'){
                        $h1class = 'bg'.$bg;
                    }elseif($layout == 'layout2'){
                        $h1class = 'text-left';
                    }else{
                        $h1class = 'text-left';
                    }
                    if($count == 3 && $layout == 'layout1'){
                      echo '<div class="last-wrap">';
                    }
                    ?>
                    <div class="portfolio-wrap nopad port-<?php echo esc_attr($count);?>">
                        <div class="our-work">
                            <figure>
                              <a href="<?php the_post_thumbnail_url('full');?>" data-lightbox="image-1" data-title="<?php the_title();?>">
                              	<img src="<?php the_post_thumbnail_url($image_size);?>" alt="<?php the_title_attribute();?>">
                                <?php if($layout == 'layout2'){?>
                                <div class="overlay"></div>
                                <?php }?>
                              </a>
                            </figure>
                            <h4 class="<?php echo esc_attr($h1class);?>">
                            	<a href="javascript:void(0);">
                            		<span class="sub-title"><?php the_title();?></span>
                            		<?php if($company){ echo esc_html($company); }?>
                            	</a>
                            </h4>
                        </div>
                    </div>
                    <?php
                    if(($count == 4 || $count==$total) && $layout == 'layout1'){
                      echo '</div>';
                    }
                endwhile;
                wp_reset_postdata();
                ?>
            </div>
            <?php
        }    
        endif;    
    }

   protected function content_template() {}

   public function render_plain_content( $instance = [] ) {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Widget_Kath_Portfolio() );