<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Widget_Kath_Team extends Widget_Base {

   public function get_name() {
   return 'kath-team';
   }

   public function get_title() {
      return __( 'Kath Team', 'kath-custom-elements' );
   }

   public function get_icon() {
      // Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
      return 'eicon-person';
   }

   public function get_categories() {
      return [ 'kath-custom-elements' ];
   }

    public function get_script_depends() {
        return [
            'kath-custom-elements-slick-script',
            'kath-custom-elements-frontend-script',
        ];
    }

   protected function _register_controls() {

      $this->start_controls_section(
         'kath_section_team',
         [
            'label' => __( 'Kath Team Settings', 'kath-custom-elements' )
         ]
      );

      $this->add_control(
         'post_type',
         [
            'label' => __( 'Select Posts Type', 'kath-custom-elements' ),
            'type' => Controls_Manager::SELECT,
            'default' => 'latest',
            'options' => [
               'latest' => __( 'Latest', 'kath-custom-elements' ),
               'category' => __( 'Category', 'kath-custom-elements' ),
            ]
         ]
      );

      $this->add_control(
         'category',
         [
         'label' => __( 'Categories', 'kath-custom-elements' ),
         'type' => Controls_Manager::SELECT,
         'label_block' => true,
         'options' => kath_post_type_categories('testi_cat'),
         'condition' => [
            'post_type' => 'category'
          ]
         ]
      );

      $this->add_control(
         'posts_per_page',
         [
            'label' => __( 'Posts Per page', 'kath-custom-elements' ),
            'type' => Controls_Manager::NUMBER,
            'default' => '4',
            'title' => __( 'Enter Posts Per Page', 'kath-custom-elements' ),
         ]
      );

      $this->add_control(
         'posts_offset',
         [
            'label' => __( 'Posts Offset', 'kath-custom-elements' ),
            'type' => Controls_Manager::NUMBER,
            'default' => '0',
            'title' => __( 'Enter Offset Value', 'kath-custom-elements' ),
         ]
      );  

        $this->add_control(
            'post_order',
            [
                'label' => __( 'Order', 'kath-custom-elements' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' => __( 'Ascending', 'kath-custom-elements' ),
                    'desc' => __( 'Descending', 'kath-custom-elements' )
                ],
                'default' => 'desc',
            ]
        ); 

        $this->add_control(
            'team_layout',
            [
                'label' => __( 'Layout', 'kath-custom-elements' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'slide' => __( 'Slide', 'kath-custom-elements' ),
                    'normal' => __( 'Normal', 'kath-custom-elements' )
                ],
                'default' => 'slide',
            ]
        ); 

        $this->add_control(
            'column_no',
            [
                'label' => __( 'Column No.', 'kath-custom-elements' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => __( '1', 'kath-custom-elements' ),
                    '2' => __( '2', 'kath-custom-elements' ),
                    '3' => __( '3', 'kath-custom-elements' ),
                    '4' => __( '4', 'kath-custom-elements' ),
                ],
                'default' => '3',
                'condition'     => [
                        'team_layout' => 'normal'
                    ]
            ]
        );   

      $this->end_controls_section();
      
      //Slider Settings
	    $this->start_controls_section(
	         'kath_section_team_slider',
	         [
	            'label' => __( 'Slider Settings', 'kath-custom-elements' )
	         ]
	    );

      	$this->add_control(
	         'show_items',
	         [
	            'label' => __( 'Items to show', 'kath-custom-elements' ),
	            'type' => Controls_Manager::NUMBER,
	            'default' => '3',
	         ]
      	); 

      	$this->add_control(
	         'scroll_items',
	         [
	            'label' => __( 'Items to scroll', 'kath-custom-elements' ),
	            'type' => Controls_Manager::NUMBER,
	            'default' => '1',
	         ]
      	); 

	    $this->add_control('auto_play',
	        [
	            'label'         => esc_html__('Auto Play', 'kath-custom-elements'),
	            'type'          => Controls_Manager::SWITCHER,
	        ]
	    );

	    $this->add_control('show_arrow',
	        [
	            'label'         => esc_html__('Show Arrow', 'kath-custom-elements'),
	            'type'          => Controls_Manager::SWITCHER,
	        ]
	    );

	    $this->add_control('show_dots',
	        [
	            'label'         => esc_html__('Show Dots', 'kath-custom-elements'),
	            'type'          => Controls_Manager::SWITCHER,
	            'default'       => 'yes'
	        ]
	    );    

      $this->end_controls_section();

      $this->start_controls_section(
         'kath_team_style',
         [
            'label' => __( 'Colors & Typography', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE
         ]
      );

      $this->add_control(
          'title_style',
          [
              'label'                 => __( 'Title Style', 'uncode-addons' ),
              'type'                  => Controls_Manager::HEADING,
          ]
      );

      $this->add_control(
         'kath_title_color',
         [
            'label' => __( 'Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
               '{{WRAPPER}} .expert-team-slider h3.member-name' => 'color: {{VALUE}}',
            ]

         ]
      );

      $this->add_group_control(
         Group_Control_Typography::get_type(),
         [
            'name' => 'kath_title_typo',
            'label' => esc_html__( 'Typography', 'kath-custom-elements' ),
            'selector' => '{{WRAPPER}} .expert-team-slider h3.member-name',
         ]
      );

      $this->add_control(
          'position_style',
          [
              'label'                 => __( 'Position Style', 'uncode-addons' ),
              'type'                  => Controls_Manager::HEADING,
          ]
      );

      $this->add_control(
         'kath_position_color',
         [
            'label' => __( 'Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
               '{{WRAPPER}} .expert-team-slider h3.member-name small' => 'color: {{VALUE}}',
            ]

         ]
      );

      $this->add_group_control(
         Group_Control_Typography::get_type(),
         [
            'name' => 'kath_position_typo',
            'label' => esc_html__( 'Typography', 'kath-custom-elements' ),
            'selector' => '{{WRAPPER}} .expert-team-slider h3.member-name small',
         ]
      );

      $this->end_controls_section();
   }

    protected function render( ) {

		// get our input from the widget settings.
		$settings = $this->get_settings();
    $layout = $settings['team_layout'];
    $column_no = $settings['column_no'];

		$post_type = $settings['post_type'];
		$per_page = $settings['posts_per_page'];
		$offset = $settings['posts_offset'];
		$order = $settings['post_order'];
		$cat_id = $settings['category'];

        $args = array(
        	'post_type'         => 'yeti_team',
        	'posts_per_page'    => $per_page,
        	'offset'            => $offset,
        	'order'             => $order,
        	'orderby'           => 'ID',
        );
        if( $post_type == 'category' ){
        	$args['tax_query'] = array(
                array(
                    'taxonomy' => 'testi_cat',
                    'field' => 'term_id',
                    'terms'    => explode(',',$cat_id)
                ),
        		);
        }

        //Slider Settings
        $auto_play = $settings['auto_play'];
        if($auto_play == 'yes'){
        	$auto_play = true;
        }else{
        	$auto_play = false;
        }
        $show_arrow = $settings['show_arrow'];
        if($show_arrow == 'yes'){
        	$show_arrow = true;
        }else{
        	$show_arrow = false;
        }
        $show_dots = $settings['show_dots'];
        if($show_dots == 'yes'){
        	$show_dots = true;
        }else{
        	$show_dots = false;
        }

        $slider_options = [
            'autoplay' => $auto_play,
            'dots' => $show_dots,
            'arrows' => $show_arrow,
            'items' => $settings['show_items'],
            'scroll' => $settings['scroll_items'],
        ];

        if($layout == 'slide'){
          $class = 'expert-team-slider';
          $col_class = 'tem';
        }else{
          $class = 'expert-team-normal';
          $col = 12/$column_no;
          $col_class = 'col-md-'.$col.' col-sm-6 col-xs-6';
        }
        $posts = new \WP_Query( $args );
        if( $posts->have_posts() ):
		    ?>
			<div class="<?php echo esc_attr($class);?>" <?php if($layout=='slide'){?>data-settings='<?php echo wp_json_encode($slider_options); ?>' <?php }?>>
          <?php 
          if($layout == 'normal'){
          echo '<div class="row">'; 
          }
          ?>
                <?php
                $count = 0; 
                $bg = 9;
                while( $posts->have_posts() ): $posts->the_post();
                    $count++;
                    $bg++;
                	$meta = get_post_meta(get_the_ID(),'yeti_team_option',true);
                	$position = isset($meta['position']) ? $meta['position'] : '';
                	$fb = isset($meta['fb']) ? $meta['fb'] : '';
                	$twit = isset($meta['twit']) ? $meta['twit'] : '';
                	$insta = isset($meta['insta']) ? $meta['insta'] : '';
                    ?>    
					<div class="<?php echo esc_attr($col_class);?>">
						<div class="expert-team">
							<figure>
								<img src="<?php the_post_thumbnail_url('yeti-team-el');?>" alt="<?php echo esc_attr__('Team Image','kath-custom-elements');?>">
								<figcaption>
								    <?php if($fb){?>
									<a href="<?php echo esc_url($fb);?>"><i class="fa fa-facebook"></i></a>
									<?php } if($insta){?>
									<a href="<?php echo esc_url($insta);?>"><i class="fa fa-instagram"></i></a>
									<?php } if($twit){?>
									<a href="<?php echo esc_url($twit);?>"><i class="fa fa-twitter"></i></a>
									<?php }?>
								</figcaption>
							</figure>
							<h3 class="text-center font2 member-name">
								<?php the_title();?>
	                            <?php if($position){ ?>
	                        		<small><?php echo esc_html($position);?></small>
	                        	<?php }?>
							</h3>
						</div>
					</div>
                    <?php
                endwhile;
                wp_reset_postdata();
                ?>
            <?php 
            if($layout == 'normal'){
            echo '</div>'; 
            }
            ?>
          </div>   
            <?php
        endif;    
    }

   protected function content_template() {}

   public function render_plain_content( $instance = [] ) {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Widget_Kath_Team() );