<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Widget_Kath_Testimonial extends Widget_Base {

   public function get_name() {
   return 'kath-testimonial';
   }

   public function get_title() {
      return __( 'Kath Testimonial', 'kath-custom-elements' );
   }

   public function get_icon() {
      // Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
      return 'eicon-testimonial';
   }

   public function get_categories() {
      return [ 'kath-custom-elements' ];
   }

    public function get_script_depends() {
        return [
            'kath-custom-elements-slick-script',
            'kath-custom-elements-frontend-script',
        ];
    }

   protected function _register_controls() {

      $this->start_controls_section(
         'kath_section_testimonial',
         [
            'label' => __( 'Kath Testimonial Settings', 'kath-custom-elements' )
         ]
      );

      $this->add_control(
         'post_type',
         [
            'label' => __( 'Select Posts Type', 'kath-custom-elements' ),
            'type' => Controls_Manager::SELECT,
            'default' => 'latest',
            'options' => [
               'latest' => __( 'Latest', 'kath-custom-elements' ),
               'category' => __( 'Category', 'kath-custom-elements' ),
            ]
         ]
      );

      $this->add_control(
         'category',
         [
         'label' => __( 'Categories', 'kath-custom-elements' ),
         'type' => Controls_Manager::SELECT,
         'label_block' => true,
         'options' => kath_post_type_categories('testi_cat'),
         'condition' => [
            'post_type' => 'category'
          ]
         ]
      );

      $this->add_control(
         'posts_per_page',
         [
            'label' => __( 'Posts Per page', 'kath-custom-elements' ),
            'type' => Controls_Manager::NUMBER,
            'default' => '4',
            'title' => __( 'Enter Posts Per Page', 'kath-custom-elements' ),
         ]
      );

      $this->add_control(
         'posts_offset',
         [
            'label' => __( 'Posts Offset', 'kath-custom-elements' ),
            'type' => Controls_Manager::NUMBER,
            'default' => '0',
            'title' => __( 'Enter Offset Value', 'kath-custom-elements' ),
         ]
      );  

        $this->add_control(
            'post_order',
            [
                'label' => __( 'Order', 'kath-custom-elements' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' => __( 'Ascending', 'kath-custom-elements' ),
                    'desc' => __( 'Descending', 'kath-custom-elements' )
                ],
                'default' => 'desc',
            ]
        );
        $this->add_control(
            'testimonial_layout',
            [
                'label' => __( 'Layout', 'kath-custom-elements' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout1' => __( 'Layout1', 'kath-custom-elements' ),
                    'layout2' => __( 'Layout2', 'kath-custom-elements' )
                ],
                'default' => 'layout1',
            ]
        );
   
      $this->end_controls_section();

      //Slider Settings
      $this->start_controls_section(
           'kath_section_quote_settings',
           [
              'label' => __( 'Quote Settings', 'kath-custom-elements' )
           ]
      );

      $this->add_control('show_quote',
          [
              'label'         => esc_html__('Show / Hide Quote', 'kath-custom-elements'),
              'type'          => Controls_Manager::SWITCHER,
          ]
      );

      $this->add_control('quote_icon',
        [
            'label'         => esc_html__('Icon', 'kath-custom-elements'),
            'type'          => Controls_Manager::ICON,
            'default'       => 'fa fa-quote-left',
            'label_block'   => true,
        ]
      );


      $this->add_control(
          'quote_position',
          [
              'label' => __( 'Quote Position', 'kath-custom-elements' ),
              'type' => Controls_Manager::SELECT,
              'options' => [
                  'top' => __( 'Top', 'kath-custom-elements' ),
                  'inline' => __( 'Inline', 'kath-custom-elements' )
              ],
              'default' => 'top',
          ]
      );

      $this->end_controls_section(); 

      //Slider Settings
	    $this->start_controls_section(
	         'kath_section_testimonial_slider',
	         [
	            'label' => __( 'Slider Settings', 'kath-custom-elements' )
	         ]
	    );

	    $this->add_control('auto_play',
	        [
	            'label'         => esc_html__('Auto Play', 'kath-custom-elements'),
	            'type'          => Controls_Manager::SWITCHER,
	        ]
	    );

	    $this->add_control('show_arrow',
	        [
	            'label'         => esc_html__('Show Arrow', 'kath-custom-elements'),
	            'type'          => Controls_Manager::SWITCHER,
	        ]
	    );

	    $this->add_control('show_dots',
	        [
	            'label'         => esc_html__('Show Dots', 'kath-custom-elements'),
	            'type'          => Controls_Manager::SWITCHER,
	            'default'       => 'yes'
	        ]
	    );    

      $this->end_controls_section();


      $this->start_controls_section(
         'testimonial_quote_styles',
         [
            'label' => __( 'Quote Styles', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE
         ]
      );


      $this->add_control(
         'quote_color',
         [
            'label' => __( 'Quote Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default' => '#ee6935',
            'selectors' => [
               '{{WRAPPER}} .quote-icon' => 'color: {{VALUE}}',
            ]

         ]
      );
        $this->add_responsive_control(
            'quote_size',
            [
                'label'                 => __( 'Quote Size', 'kath-custom-elements' ),
                'type'                  => Controls_Manager::SLIDER,
                'default'               => [
                    'size'      => '45',
                    'unit'      => 'px',
                ],
                'range'                 => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 100,
                        'step'  => 1,
                    ],
                ],
                'size_units'            => [ 'px', '%' ],
                'selectors'             => [
                    '{{WRAPPER}} .quote-icon' => 'font-size: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

      $this->end_controls_section();

      $this->start_controls_section(
         'testimonial_styles',
         [
            'label' => __( 'Content Styles', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE
         ]
      );

      $this->add_control(
         'testimonial_content_color',
         [
            'label' => __( 'Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default' => '#fff',
            'selectors' => [
               '{{WRAPPER}} p' => 'color: {{VALUE}}',
            ]

         ]
      );

      $this->add_group_control(
         Group_Control_Typography::get_type(),
         [
            'name' => 'testimonial_content_typo',
            'label' => esc_html__( 'Typography', 'kath-custom-elements' ),
            'selector' => '{{WRAPPER}} p',
         ]
      );

      $this->end_controls_section();

      $this->start_controls_section(
         'testimonial_name_styles',
         [
            'label' => __( 'Name Styles', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE
         ]
      );

      $this->add_control(
         'testimonial_cname_color',
         [
            'label' => __( 'Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default' => '#5031a9',
            'selectors' => [
               '{{WRAPPER}} h3' => 'color: {{VALUE}}',
            ]

         ]
      );

      $this->add_group_control(
         Group_Control_Typography::get_type(),
         [
            'name' => 'testimonial_cname_typo',
            'label' => esc_html__( 'Typography', 'kath-custom-elements' ),
            'selector' => '{{WRAPPER}} h3',
         ]
      );

      $this->end_controls_section();

      $this->start_controls_section(
         'testimonial_position_styles',
         [
            'label' => __( 'Position Styles', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE
         ]
      );

      $this->add_control(
         'testimonial_cposition_color',
         [
            'label' => __( 'Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default' => '#fff',
            'selectors' => [
               '{{WRAPPER}} h3 small' => 'color: {{VALUE}}',
            ]

         ]
      );

      $this->add_group_control(
         Group_Control_Typography::get_type(),
         [
            'name' => 'testimonial_cposition_typo',
            'label' => esc_html__( 'Typography', 'kath-custom-elements' ),
            'selector' => '{{WRAPPER}} h3 small',
         ]
      );

      $this->end_controls_section();
   }

    protected function render( ) {

		// get our input from the widget settings.
		$settings = $this->get_settings();
    $layout = $settings['testimonial_layout'];

		$post_type = $settings['post_type'];
		$per_page = $settings['posts_per_page'];
		$offset = $settings['posts_offset'];
		$order = $settings['post_order'];
		$cat_id = $settings['category'];

    $show_quote = $settings['show_quote'];
    $quote_icon = $settings['quote_icon'];
    $quote_color = $settings['quote_color'];
    $quote_position = $settings['quote_position'];


        $args = array(
        	'post_type'         => 'yeti_testimonial',
        	'posts_per_page'    => $per_page,
        	'offset'            => $offset,
        	'order'             => $order,
        	'orderby'           => 'ID',
        );
        if( $post_type == 'category' ){
        	$args['tax_query'] = array(
                array(
                    'taxonomy' => 'testi_cat',
                    'field' => 'term_id',
                    'terms'    => explode(',',$cat_id)
                ),
        		);
        }

        //Slider Settings
        $auto_play = $settings['auto_play'];
        if($auto_play == 'yes'){
        	$auto_play = true;
        }else{
        	$auto_play = false;
        }
        $show_arrow = $settings['show_arrow'];
        if($show_arrow == 'yes'){
        	$show_arrow = true;
        }else{
        	$show_arrow = false;
        }
        $show_dots = $settings['show_dots'];
        if($show_dots == 'yes'){
        	$show_dots = true;
        }else{
        	$show_dots = false;
        }

        $slider_options = [
            'autoplay' => $auto_play,
            'dots' => $show_dots,
            'arrows' => $show_arrow
        ];
        if($layout == 'layout1'){
          $class = 'paragraph';
        }else{
          $class = 'about-us-quote';
        }

        $posts = new \WP_Query( $args );
        if( $posts->have_posts() ):
		    ?>
      <div class="testimonials-slider <?php if($layout == 'layout1'){?>text-center <?php }?>" data-settings='<?php echo wp_json_encode($slider_options); ?>'>
                <?php
                $count = 0; 
                $bg = 9;
                while( $posts->have_posts() ): $posts->the_post();
                    $count++;
                    $bg++;
                  $meta = get_post_meta(get_the_ID(),'yeti_testimonials_option',true);
                  $position = isset($meta['position']) ? $meta['position'] : '';
                    ?>
                  <div>
                    <div class="<?php echo esc_attr($class);?>">
                      <?php if($show_quote == 'yes' && $quote_position == 'top'){?>
                      <i class="<?php echo esc_attr($quote_icon);?> quote-icon"></i>
                      <?php }?>
                      <p>
                        <?php if($show_quote == 'yes' && $quote_position == 'inline'){?>
                        <i class="<?php echo esc_attr($quote_icon);?>"></i>
                        <?php }?>
                        <?php echo get_the_content();?>
                      </p>
                    </div>
                    <h3 class="font2">
                        <?php
                        the_title();
                        if($position){ ?>
                        <small><?php echo esc_html($position);?></small>
                      <?php }?> 
                    </h3>
                  </div>
                    <?php
                endwhile;
                wp_reset_postdata();
                ?>
            </div>
            <?php
        endif;     
    }

   protected function content_template() {}

   public function render_plain_content( $instance = [] ) {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Widget_Kath_Testimonial() );