<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Widget_Kath_Timeline extends Widget_Base {

    public function get_name() {
        return 'uad-timeline';
    }
    
    public function get_title() {
        return __( 'Timeline', 'kath-custom-elements' );
    }

    public function get_icon() {
        return 'eicon-time-line';
    }

    public function get_categories() {
        return [ 'kath-custom-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'timeline_settings',
            [
                'label' => __( 'Timeline Settings', 'kath-custom-elements' ),
            ]
        );

            $this->add_control(
              'uad_timeline_style',
                [
                'label'         => esc_html__( 'Display Style', 'kath-custom-elements' ),
                    'type'          => Controls_Manager::SELECT,
                    'default'       => 'horizontal',
                    'label_block'   => false,
                    'options'       => [
                        'horizontal'    => esc_html__( 'Horizontal', 'kath-custom-elements' ),
                        'vertical'   => esc_html__( 'Vertical', 'kath-custom-elements' ),
                    ],
                ]
            );
            $this->add_control(
              'uad_viewport_item',
                [
                'label' => esc_html__( 'Viewport Item', 'kath-custom-elements' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 4,
                'min' => 1,
                'max' => 8,  
                'condition' => ['uad_timeline_style' => 'horizontal']
                ]
            );
            
        $this->end_controls_section();

         // Timeline Content
        $this->start_controls_section(
            'uad_timeline_content',
            [
                'label' => __( 'Content Settings', 'kath-custom-elements' ),
            ]
        );

            $repeater = new Repeater();

            $repeater->add_control(
                'image_show',
                [
                    'label' => esc_html__( 'Show Image', 'kath-custom-elements' ),
                    'type' => Controls_Manager::SWITCHER,
                    'default' => 'no',
                    'return_value' => 'yes',
                ]
            );
            $repeater->add_control(
              'timeline_image',
              [
                 'label' => esc_html__( 'Image', 'kath-custom-elements' ),
                 'type' => Controls_Manager::MEDIA,
                 'condition' => ['image_show' => 'yes']
              ]
            );

            $repeater->add_control(
                'content_date',
                [
                    'label'   => __( 'Content Date', 'kath-custom-elements' ),
                    'type'    => Controls_Manager::TEXT,
                    'default' => __( 'Sep 2018', 'kath-custom-elements' ),
                ]
            );

            $repeater->add_control(
                'content_title',
                [
                    'label'   => __( 'Title', 'kath-custom-elements' ),
                    'type'    => Controls_Manager::TEXT,
                ]
            );

            $repeater->add_control(
                'content_text',
                [
                    'label' => __( 'Content', 'kath-custom-elements' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => __( 'Lorem ipsum dolor sit amet, consectetur adipis icing elit, sed do eiusmod tempor incid ut labore et dolore magna aliqua Ut enim ad min.', 'kath-custom-elements' ),
                ]
            );

            $this->add_control(
                'custom_content_list',
                [
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => array_values( $repeater->get_controls() ),
                    'default' => [
                        [   
                            'content_title' => __( 'Title #1', 'kath-custom-elements' ),
                            'content_date' => __( 'Sep 2018', 'kath-custom-elements' ),
                            'content_text' => __( 'Lorem ipsum dolor sit amet, consectetur adipis icing elit, sed do eiusmod tempor incid ut labore et dolore magna aliqua Ut enim ad min.', 'kath-custom-elements' ),
                        ],
                        [
                            'content_title' => __( 'Title #2', 'kath-custom-elements' ),
                            'content_date' => __( 'Oct 2018', 'kath-custom-elements' ),
                            'content_text' => __( 'Lorem ipsum dolor sit amet, consectetur adipis icing elit, sed do eiusmod tempor incid ut labore et dolore magna aliqua Ut enim ad min.', 'kath-custom-elements' ),
                        ],
                        [
                            'content_title' => __( 'Title #3', 'kath-custom-elements' ),
                            'content_date' => __( 'Aug 2018', 'kath-custom-elements' ),
                            'content_text' => __( 'Lorem ipsum dolor sit amet, consectetur adipis icing elit, sed do eiusmod tempor incid ut labore et dolore magna aliqua Ut enim ad min.', 'kath-custom-elements' ),
                        ]

                    ],
                    'title_field' => '{{{ content_title }}}',
                ]
            );

        $this->end_controls_section();

        /* Content Styles */
		$this->start_controls_section(
			'uad_content_style_settings',
			[
				'label' => esc_html__( 'Content Styles ', 'kath-custom-elements' ),
				'tab' => Controls_Manager::TAB_STYLE
			]
		);

            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'content_background',
                    'label' => __( 'Background', 'kath-custom-elements' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .uad-timeline .timeline-main-wrapper',
                ]
            );

            $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                    'name' => 'content_border',
                    'label' => __( 'Border', 'kath-custom-elements' ),
                    'selector' => '{{WRAPPER}} .uad-timeline .timeline-main-wrapper', 
                ]
            );

            $this->add_responsive_control(
                'content_border_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'kath-custom-elements' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .uad-timeline .timeline-main-wrapper' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;'
                    ],
                    'separator' => 'before',
                ]
            );

            $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                    'name' => 'content_box_shadow',
                    'label' => __( 'Box Shadow', 'kath-custom-elements' ),
                    'selector' => '{{WRAPPER}} .uad-timeline .timeline-main-wrapper',
                    'separator' => 'before',
                ]
            );

            $this->add_responsive_control(
                'content_padding',
                [
                    'label' => __( 'Padding', 'kath-custom-elements' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .uad-timeline .timeline-main-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                    ],
                    'separator' => 'before',
                ]
            );
            $this->add_responsive_control(
                'content_margin',
                [
                    'label' => __( 'Margin', 'kath-custom-elements' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .uad-timeline .timeline-main-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                    ],
                    'separator' => 'before',
                ]
            );
			$this->add_control(
				'uad_line_color',
				[
					'label' => esc_html__( 'Line Color', 'kath-custom-elements' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .uad-timeline:after, {{WRAPPER}} .uad-timeline ol li:after' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .uad-timeline ol li:after' => 'border-color: {{VALUE}};',

					],
				]
			);
		$this->end_controls_section();

        /* Date Styles */
		$this->start_controls_section(
			'uad_date_style_settings',
			[
				'label' => esc_html__( 'Date Style ', 'kath-custom-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
             'name' => 'uad_date_typography',
				'selector' => '{{WRAPPER}} .uad-timeline .steps-wrap',
			]
		);

		$this->add_control(
			'uad_date_color',
			[
				'label' => esc_html__( 'Text Color', 'kath-custom-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .uad-timeline .steps-wrap' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'uad_date_padding',
			[
				'label' => esc_html__( 'Padding', 'kath-custom-elements' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
	 					'{{WRAPPER}} .uad-timeline .steps-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	 			],
			]
		);

		$this->add_responsive_control(
			'uad_date_margin',
			[
				'label' => esc_html__( 'Margin', 'kath-custom-elements' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
	 					'{{WRAPPER}} .uad-timeline .steps-wrap' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	 			],
			]
		);

		$this->end_controls_section();

        /* Image Styles */
        $this->start_controls_section(
            'uad_image_style_settings',
            [
                'label' => esc_html__( 'Image Style ', 'kath-custom-elements' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'image_size',
            [
                'label'                 => __( 'Spacing', 'power-pack' ),
                'type'                  => Controls_Manager::SLIDER,
                'size_units'            => [ '%', 'px' ],
                'default'               => [
                    'size' => 100,
                    'unit' => '%',
                ],
                'range'                 => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'tablet_default'        => [
                    'unit' => '%',
                ],
                'mobile_default'        => [
                    'unit' => '%',
                ],
                'selectors'             => [
                    '{{WRAPPER}} .uad-timeline .timeline-image img' => 'width: {{SIZE}}{{UNIT}};'
                ],
                'separator'             => 'before',
            ]
        );

        $this->add_responsive_control(
            'uad_image_padding',
            [
                'label' => esc_html__( 'Padding', 'kath-custom-elements' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                        '{{WRAPPER}} .uad-timeline .timeline-image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();

        /* Title Styles */
		$this->start_controls_section(
			'uad_title_style_settings',
			[
				'label' => esc_html__( 'Title Style ', 'kath-custom-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'uad_title_alignment',
			[
				'label' => __( 'Title Alignment', 'kath-custom-elements' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'kath-custom-elements' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'kath-custom-elements' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'kath-custom-elements' ),
						'icon' => 'fa fa-align-right',
					]
				],
				'selectors' => [
					'{{WRAPPER}} .uad-timeline .main-timeline-title' => 'text-align: {{VALUE}};',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
             'name' => 'uad_title_typography',
				'selector' => '{{WRAPPER}} .uad-timeline .main-timeline-title',
			]
		);

		$this->add_control(
			'uad_title_color',
			[
				'label' => esc_html__( 'Text Color', 'kath-custom-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .uad-timeline .main-timeline-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'uad_title_padding',
			[
				'label' => esc_html__( 'Padding', 'kath-custom-elements' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
	 					'{{WRAPPER}} .uad-timeline .main-timeline-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	 			],
			]
		);

		$this->end_controls_section();

        /* Content Styles */
		$this->start_controls_section(
			'uad_desc_style_settings',
			[
				'label' => esc_html__( 'Description Style ', 'kath-custom-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'uad_desc_alignment',
			[
				'label' => __( 'Content Alignment', 'kath-custom-elements' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'kath-custom-elements' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'kath-custom-elements' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'kath-custom-elements' ),
						'icon' => 'fa fa-align-right',
					]
				],
				'selectors' => [
					'{{WRAPPER}} .uad-timeline .desc' => 'text-align: {{VALUE}};',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
             'name' => 'uad_cat_desc_typography',
				'selector' => '{{WRAPPER}} .uad-timeline .desc p',
			]
		);

		$this->add_control(
			'uad_desc_color',
			[
				'label' => esc_html__( 'Text Color', 'kath-custom-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .uad-timeline .desc p' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'uad_desc_padding',
			[
				'label' => esc_html__( 'Padding', 'kath-custom-elements' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
	 					'{{WRAPPER}} .uad-timeline .desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	 			],
			]
		);

		$this->end_controls_section();

    }

    protected function render( $instance = [] ) {

        $settings   = $this->get_settings_for_display();
        $timeline_style = $settings['uad_timeline_style'];
        $viewport_item = $settings['uad_viewport_item'];

        $this->add_render_attribute( 'uad_timeline', 'class', 'uad-timeline timeline-'.$timeline_style.' item-'.$viewport_item );
    
        ?>
        <div <?php echo $this->get_render_attribute_string( 'uad_timeline' ); ?>>
            <ol>
            <?php
                $i = 0;
                if( isset( $settings['custom_content_list'] ) ):
                    foreach ( $settings['custom_content_list'] as $items ):
                        $i++;
                        if( $i%2 == 0 ){
                            $class = 'reverse';
                        }else{
                            $class = '';
                        }
                        $image_id = isset($items['timeline_image']['url']) ? $items['timeline_image']['url'] : '';

                        ?>
                        <li>
                            <?php if(!empty($items['content_date'])){?>
                            <h5 class="steps-wrap"><?php echo wp_kses_post($items['content_date']); ?></h5>
                            <?php }?>
                            <div class="timeline-main-wrapper">
                                <?php if($image_id!='' && $items['image_show'] == 'yes'){ ?>
                                <figure class="timeline-image">
                                    <img src="<?php echo esc_url($image_id);?>" alt="<?php echo esc_attr__('Timeline Image','kath-custom-elements');?>">
                                </figure>
                                <?php }?>
                                <div class="main-timeline-txt-content">
                                    <?php if( !empty( $items['content_title']) ){?>
                                    <h5 class="main-timeline-title"><?php echo wp_kses_post($items['content_title']);?></h5>
                                    <?php }?>
                                    <?php if( !empty( $items['content_text']) ){?>
                                    <div class="des">
                                        <?php echo wp_kses_post($items['content_text']);?>
                                    </div>
                                    <?php }?>
                                </div>
                            </div>
                        </li>
                        <?php 
                    endforeach; 
                endif; 
            ?>
            </ol>
        </div>

        <?php

    }

}

Plugin::instance()->widgets_manager->register_widget_type( new Widget_Kath_Timeline() );