<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Widget_Kath_Vpopup extends Widget_Base {

   public function get_name() {
   return 'kath-vpopup';
   }

   public function get_title() {
      return __( 'Video Popup', 'kath-custom-elements' );
   }

   public function get_icon() {
      // Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
      return 'eicon-play';
   }

   public function get_categories() {
      return [ 'kath-custom-elements' ];
   }

   protected function _register_controls() {

      $this->start_controls_section(
         'kath_section_vpopup',
         [
            'label' => __( 'Popup Settings', 'kath-custom-elements' )
         ]
      );

      $this->add_control(
         'display_type',
         [
            'label' => __( 'Display Type', 'kath-custom-elements' ),
            'type' => Controls_Manager::SELECT,
            'default' => 'icon',
            'options' => [
               'icon' => __( 'Icon', 'kath-custom-elements' ),
               'image' => __( 'Image', 'kath-custom-elements' ),
            ]
         ]
      );

      $this->add_control('display_image',
        [
            'label'         => esc_html__('Image', 'kath-custom-elements'),
            'description'   => esc_html__('Choose an image for the video Popup', 'kath-custom-elements' ),
            'type'          => Controls_Manager::MEDIA,
            'default'       => [
                'url' => Utils::get_placeholder_image_src()
            ],
            'label_block'   => true,
            'condition'     => ['display_type'=>'image']
        ]
      );

      $this->add_control('display_icon', 
        [
            'label'         => esc_html__('Select an Icon', 'kath-custom-elements'),
            'type'          => Controls_Manager::ICON,
            'default'       => 'fa fa-play',
            'condition'     => ['display_type'=>'icon']
        ]
      );

      $this->add_control(
         'video_type',
         [
            'label' => __( 'Video Type', 'kath-custom-elements' ),
            'type' => Controls_Manager::SELECT,
            'default' => 'youtube',
            'options' => [
               'youtube' => __( 'Youtube', 'kath-custom-elements' ),
               'vimeo' => __( 'Vimeo', 'kath-custom-elements' ),
            ]
         ]
      );

      $this->add_control(
         'video_url',
         [
            'label' => __( 'Enter Video URL', 'kath-custom-elements' ),
            'type' => Controls_Manager::TEXT,
         ]
      ); 


      $this->add_control(
        'autoplay',
        [
          'label'     => __( 'Autoplay', 'kath-custom-elements' ),
          'type'      => Controls_Manager::SWITCHER,
          'default'     => 'no',
          'yes'    => __( 'Yes', 'kath-custom-elements' ),
          'no'    => __( 'No', 'kath-custom-elements' ),
        ]
      );
       
      $this->end_controls_section();
          
      //Styles
      $this->start_controls_section(
         'vpopup_style',
         [
            'label' => __( 'Styles', 'kath-custom-elements' ),
            'tab' => Controls_Manager::TAB_STYLE,
         ]
      );

      $this->start_controls_tabs( 'tabs_button_style' );
      
      $this->start_controls_tab(
          'tab_icon_normal',
          [
              'label'                 => __( 'Normal', 'kath-custom-elements' ),
          ]
      );

      $this->add_control(
         'icon_color',
         [
            'label' => __( 'Icon Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default' => '#5031a9',
            'selectors' => [
               '{{WRAPPER}} .js-video-popup' => 'color: {{VALUE}}',
            ],
            'condition'             => [
                    'display_type'  => 'icon',
            ],

         ]
      );

      $this->add_control(
         'bg_color',
         [
            'label' => __( 'Background Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default' => '#fff',
            'selectors' => [
               '{{WRAPPER}} .js-video-popup' => 'background-color: {{VALUE}}',
            ],
            'condition'             => [
                    'display_type'  => 'icon',
            ],

         ]
      );

        $this->add_group_control(
            Group_Control_Border::get_type(),
                [
                    'name'              => 'icon_border',
                    'selector'          => '{{WRAPPER}} .js-video-popup',
                    ]
                );
        
        $this->add_control('icon_border_radius',
                [
                    'label'         => esc_html__('Border Radius', 'kath-custom-elements'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .js-video-popup' => 'border-radius: {{SIZE}}{{UNIT}};'
                        ]
                    ]
                );
      $this->end_controls_tab();  

      $this->start_controls_tab(
          'tab_icon_hover',
          [
              'label'                 => __( 'Hover', 'kath-custom-elements' ),
          ]
      );

      $this->add_control(
         'icon_hcolor',
         [
            'label' => __( 'Icon Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default' => '#fff',
            'selectors' => [
               '{{WRAPPER}} .js-video-popup:hover' => 'color: {{VALUE}}',
            ],
            'condition'             => [
                    'display_type'  => 'icon',
            ],

         ]
      );

      $this->add_control(
         'bg_hcolor',
         [
            'label' => __( 'Background Color', 'kath-custom-elements' ),
            'type' => Controls_Manager::COLOR,
            'default' => '#5031a9',
            'selectors' => [
               '{{WRAPPER}} .js-video-popup:hover' => 'background-color: {{VALUE}}',
            ],
            'condition'             => [
                    'display_type'  => 'icon',
            ],

         ]
      );

        $this->add_group_control(
            Group_Control_Border::get_type(),
                [
                    'name'              => 'icon_hborder',
                    'selector'          => '{{WRAPPER}} .js-video-popup:hover',
                    ]
                );
        
        $this->add_control('icon_border_hradius',
                [
                    'label'         => esc_html__('Border Radius', 'kath-custom-elements'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .js-video-popup:hover' => 'border-radius: {{SIZE}}{{UNIT}};'
                        ]
                    ]
                );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_responsive_control(
            'icon_size',
            [
                'label'                 => __( 'Icon Size', 'wpopea' ),
                'type'                  => Controls_Manager::SLIDER,
                'default'               => [
                    'size'      => '20',
                    'unit'      => 'px',
                ],
                'range'                 => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 50,
                        'step'  => 1,
                    ],
                ],
                'size_units'            => [ 'px', '%' ],
                'selectors'             => [
                    '{{WRAPPER}} .js-video-popup' => 'font-size: {{SIZE}}{{UNIT}}',
                ],
                'condition'             => [
                    'display_type'  => 'icon',
                ],
            ]
        );

      $this->add_responsive_control(
        'icon_padding',
        [
          'label'                 => __( 'Padding', 'kath-custom-elements' ),
          'type'                  => Controls_Manager::DIMENSIONS,
          'size_units'            => [ 'px', 'em', '%' ],
          'selectors'             => [
            '{{WRAPPER}} .js-video-popup' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
          ],
        ]
      );


      $this->end_controls_section();
   }

    protected function render( ) {

  		// get our input from the widget settings.
  		$settings = $this->get_settings();

      $display_type = $settings['display_type'];
      $icon = $settings['display_icon'];
      $image = $settings['display_image'];
      $video_type = $settings['video_type'];
      $video_url = $settings['video_url'];
      $autoplay = $settings['autoplay'];
      if($autoplay == 'yes'){
        $autoplay = 'true';
      }else{
        $autoplay = 'false';
      }
      
      if($video_type == 'vimeo'){
        /* Video ID extractor*/
        $vimeoURL=$video_url;
        $videoId=preg_replace("/[^0-9]/","",$vimeoURL);
      }else{
        // detect youtube id form url 
        $youtubeURL= $video_url;
        $videoId = explode("?v=", $youtubeURL); // For videos like http://www.youtube.com/watch?v=...
        if (empty($videoId[1])){
        $videoId = explode("/v/", $youtubeURL); // For videos like http://www.youtube.com/watch/v/..
        }else{
        $videoId = explode("&", $videoId[1]); // Deleting any other params
        }       
        $videoId = $videoId[0];        
      }
      ?>
      <a class="js-video-popup play" href="#" data-video-id="<?php echo esc_attr($videoId);?>" data-play="<?php echo esc_attr($autoplay);?>">
        <?php if($display_type == 'icon'){?>
        <i class="<?php echo esc_attr($icon);?>"></i>
        <?php }else{ ?>
        <img src="<?php echo esc_url($image['url']);?>" alt="<?php echo esc_attr__('vpopup-image','kath-custom-elements');?>">
        <?php }?>
      </a>
      <?php

  
    }

   protected function content_template() {}

   public function render_plain_content( $instance = [] ) {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Widget_Kath_Vpopup() );