<?php
/**
 * Recent Comments Widget
 *
 * @package Yeti
 */

class Yeti_Recent_Comments extends Yeti_Widgets
{
    public function __construct()
    {
        parent::__construct(
            'yeti_recent_comments',
            esc_html__('*Yeti : Recent Comments', 'yeti'),
            array('description' => esc_html__('Shows Recent Comments in a list.', 'yeti') )
        );
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget($args, $instance) {
        extract($args);
        echo $args['before_widget'];
        if ( ! empty( $instance['title'] ) ) {
            echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ). $args['after_title'];
        }
        $per_page = empty($instance['no_of_comments']) ? '5' : $instance['no_of_comments'];
        $comment_args = array(
                       'status' => 'approve',
                       'number' => $per_page
                     );
        ?>
        <div class="widget_comment ">
            <ul class="comment-list">
                <?php 
                    //get recent comments
                        
                    $comments = get_comments($comment_args);
                    $count = 0;
                    foreach($comments as $comment) :    
                            $count++;                        
                            $commentcontent = strip_tags($comment->comment_content);            
                            $commentcontent = wp_trim_words( $commentcontent, 20, '...' );

                            
                            $commentauthor = $comment->comment_author;
     

                            $commentid = $comment->comment_ID;
                            $commenturl = get_comment_link($commentid); 
                            
                            $yeti_postid = $comment->comment_post_ID;
                            $title = get_the_title($yeti_postid);
                            $short_title = wp_trim_words( $title, 20, '...' );
                           ?>
                            <li class="clearfix">
                                <div class="author-comment-wrap">
                                    <h4 class="post-title">
                                        <span class="count"><?php echo esc_html($count);?></span>
                                        <a href="<?php echo get_permalink($yeti_postid) ?>"><?php echo esc_attr($short_title); ?></a>
                                    </h4>
                                    <div class="cm-header">                              
                                        <div class="author-image">
                                            <?php echo get_avatar( $comment, '150' ); ?>
                                        </div>                                 
                                        <div class="detail-wrap">
                                          <div class="author-name">
                                              <?php echo esc_attr($commentauthor); ?>
                                          </div>
                                          <div class="date">
                                              <?php echo (get_comment_date('', $commentid)); ?>
                                          </div>
                                        </div>
                                    </div> 

                                    <div class="comment-text">
                                        <a href="<?php echo esc_url($commenturl); ?>"><?php echo esc_attr($commentcontent); ?></a>
                                    </div>

                                </div>
                            </li>
                <?php endforeach; ?>
            </ul>
        </div>
        <?php
        echo $args['after_widget'];
    }

    function get_options()
    {
        return array(
            array(
              'id'      => 'title',
              'type'    => 'text',
              'title'   => esc_html__('Title:', 'yeti'),
            ),
            array(
              'id'          => 'no_of_comments',
              'type'        => 'number',
              'default'     => 4,
              'title'       => esc_html__('No. of Comments', 'yeti'),
              'attributes'  => array('min'=>'1'),
            ),
        );
    }
}
if ( ! function_exists( 'cs_widget_init_recent_comments' ) ) {
  function cs_widget_init_recent_comments() {
    register_widget( 'Yeti_Recent_Comments' );
  }
  add_action( 'widgets_init', 'cs_widget_init_recent_comments', 2 );
}