<?php
/**
 * Yeti : Recent Posts
 *
 * Widget to display latest or selected category posts as on list style.
 *
 */

class Yeti_Recent_Posts extends Yeti_Widgets
{
    public function __construct()
    {
        parent::__construct(
            'yeti_posts_list',
            esc_html__('*Yeti : Recent Posts', 'yeti'),
            array('description' => esc_html__( 'Display posts in list format.', 'yeti' ) )
        );
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget($args, $instance) {
        extract( $args );
        if( empty( $instance ) ) {
            return ;
        }
        echo $args['before_widget'];
        if ( ! empty( $instance['title'] ) ) {
            echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ). $args['after_title'];
        }
        $yeti_block_posts_count = empty( $instance['block_posts_count'] ) ? 4 : $instance['block_posts_count'];
        $yeti_block_posts_type    = empty( $instance['block_post_type'] ) ? 'latest' : $instance['block_post_type'];
        $yeti_block_cat_id    = empty( $instance['block_post_category'] ) ? null : $instance['block_post_category'];

        ?>
       <div class="post-list-wraper">
            <div class="recent-posts-wrap">
                <?php 
                $block_args= array(
								'post_type'		=> 'post',	
				                'post_status'   => 'publish',					
								'posts_per_page'=> $yeti_block_posts_count,
						    );
                if($yeti_block_posts_type == 'category'){
                	$block_args['category__in'] = $yeti_block_cat_id;
                }
                $block_query = new WP_Query( $block_args );
                if( $block_query->have_posts() ) {
                    $count = 0;
                    while( $block_query->have_posts() ) {
                        $count++;
                        $block_query->the_post();
                        $image_id = get_post_thumbnail_id();
                        if($count==1){
                        $image_path = wp_get_attachment_image_src( $image_id, 'yeti-blog-grid', true );
                        $class = 'post-large';
                        }else{
                        $image_path = wp_get_attachment_image_src( $image_id, 'thumbnail', true );
                        $class = '';
                        }

                        $image_alt = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
                        ?>
                        <div class="single-post <?php echo esc_attr($class);?>">
                            <?php 
                            if( has_post_thumbnail() ) { ?>
                            <div class="post-thumb">
                                <a class="thumb-zoom" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
                                    <img src="<?php echo esc_url( $image_path[0] ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>" title="<?php the_title_attribute(); ?>" />
                                </a>
                            </div>    
                            <?php } ?>
                            <div class="post-caption">
                                <h3 class="large-font"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                <div class="post-meta clearfix">
                                    <?php 
                                        echo get_the_date();  
                                    ?>
                                </div><!-- .post-meta --> 
                            </div>
                        </div><!-- .single-post  -->
                        <?php
                    }
                }
                wp_reset_postdata();
               ?>
            </div>
        </div><!-- .block-post-wrapper -->

        <?php
        echo $args['after_widget'];
    }

    function get_options()
    {
        return array(
            array(
                'id'      => 'title',
                'type'    => 'text',
                'title'   => esc_html__( 'Title:', 'yeti' ),
            ),
            array(
                'id'      => 'block_posts_count',
                'type'    => 'number',
                'title'   => esc_html__( 'No. of Posts', 'yeti' ),
                'default' => 4,
                'attributes' => array('min'=>'0'),
            ),
            array(
                'id'      => 'block_post_type',
                'type'    => 'radio',
                'title'   => esc_html__('Posts Type', 'yeti'),
                'options' => array(
                	         'latest' => esc_html__('Latest', 'yeti'),
                	         'category' => esc_html__('Category', 'yeti'),
                             ),
                'default' => 'latest',
                'class'   => 'horizontal',
                'attributes'   => array(
                    'data-depend-id' => 'block_post_type' 
                ),
            ),
            array(
                'id'     => 'block_post_category',
                'type'   => 'select',
                'title'  => esc_html__( 'Select Category', 'yeti'), 
                'options'=> 'categories',
                'dependency' => array('block_post_type','any','category'),
            ),
        );
    }
}
if ( ! function_exists( 'cs_widget_init_posts_list' ) ) {
  function cs_widget_init_posts_list() {
    register_widget( 'Yeti_Recent_Posts' );
  }
  add_action( 'widgets_init', 'cs_widget_init_posts_list', 2 );
}
