<?php
/**
 * yeti functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package yeti
 */

if ( ! function_exists( 'yeti_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function yeti_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on yeti, use a find and replace
		 * to change 'yeti' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'yeti', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'yeti-blog-el1', 760, 415, true );
		add_image_size( 'yeti-blog-el2', 360, 292, true );
		add_image_size( 'yeti-portfolio-odd-el2', 660, 430, true );
		add_image_size( 'yeti-portfolio-even-el2', 470, 430, true );
		add_image_size( 'yeti-team-el', 360, 363, true );
		add_image_size( 'yeti-blog-list', 1200, 585, true );
		add_image_size( 'yeti-blog-grid', 360, 292, true );
		add_image_size( 'yeti-portfolio2', 560, 445, true );
		add_image_size( 'yeti-portfolio3', 370, 270, true );
		add_image_size( 'yeti-portfolio-slider', 370, 400, true );
		add_image_size( 'yeti-single-image', 750, 750, true );
		add_image_size( 'yeti-portfolio-el', 1000, 1000, true );
		add_image_size( 'yeti-blog-full', 460, 380, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary-menu' => esc_html__( 'Primary', 'yeti' ),
			'footer-menu' => esc_html__( 'Footer', 'yeti' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'yeti_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

	    // Add support for Block Styles.
	    add_theme_support( 'wp-block-styles' );

	    // Add support for full and wide align images.
	    add_theme_support( 'align-wide' );

	    // Add custom editor font sizes.
	    add_theme_support(
	        'editor-font-sizes',
	        array(
	            array(
	                'name'      => esc_html__( 'Small', 'yeti' ),
	                'shortName' => esc_html__( 'S', 'yeti' ),
	                'size'      => 12,
	                'slug'      => 'small',
	            ),
	            array(
	                'name' => esc_html__( 'Regular', 'yeti' ),
	                'shortName' => esc_html__( 'M', 'yeti' ),
	                'size' => 15,
	                'slug' => 'regular'
	            ),
	            array(
	                'name'      => esc_html__( 'Large', 'yeti' ),
	                'shortName' => esc_html__( 'L', 'yeti' ),
	                'size'      => 32,
	                'slug'      => 'large',
	            ),
	            array(
	                'name'      => esc_html__( 'Huge', 'yeti' ),
	                'shortName' => esc_html__( 'XL', 'yeti' ),
	                'size'      => 40,
	                'slug'      => 'huge',
	            ),
	        )
	    );

	    // Editor color palette.
	    add_theme_support(
	        'editor-color-palette',
	        array(
	            array(
	                'name' => esc_html__( 'strong purple', 'yeti' ),
	                'slug' => 'strong-purple',
	                'color' => '#5029c0',
	            ),
	            array(
	                'name' => esc_html__( 'strong orange', 'yeti' ),
	                'slug' => 'strong-orange',
	                'color' => '#ff8b24',
	            ),
	            array(
	                'name' => esc_html__( 'very light gray', 'yeti' ),
	                'slug' => 'very-light-gray',
	                'color' => '#eee',
	            ),
	            array(
	                'name' => esc_html__( 'very dark gray', 'yeti' ),
	                'slug' => 'very-dark-gray',
	                'color' => '#444',
	            ),
	        )
	    );

	    // Add support for responsive embeds.
	    add_theme_support( 'responsive-embeds' );


	}
endif;
add_action( 'after_setup_theme', 'yeti_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function yeti_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'yeti_content_width', 640 );
}
add_action( 'after_setup_theme', 'yeti_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function yeti_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Default Sidebar', 'yeti' ),
		'id'            => 'default-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'yeti' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );
	// footer widgets

	for($i=1; $i<=4; $i++){

		register_sidebar( array(
			'name' 				=> sprintf( esc_html__( 'Footer Widget Area %d', 'yeti' ), $i ),
			'id' 				=> sprintf( 'footer-widgets-%d', $i ),
			'description' 		=> sprintf( esc_html__( ' Add Widgetized Footer Region %d.', 'yeti' ), $i ),
			'before_widget' 	=> '<div id="%1$s" class="widget %2$s">',
			'after_widget' 		=> '</div>',
			'before_title' 		=> '<h6 class="footer-title">',
			'after_title' 		=> '</h6>',
		));
	}

}
add_action( 'widgets_init', 'yeti_widgets_init' );

/* Remove CS options */
define( 'CS_ACTIVE_SHORTCODE', false );
define( 'CS_ACTIVE_CUSTOMIZE', false );
define( 'CS_ACTIVE_TAXONOMY', false );

/* Require theme files*/
$file_paths = array(
	'/inc/core/constants.php',
    '/inc/core/enqueue.php',
    '/inc/core/yeti-functions.php',
	'/inc/custom-header.php',
	'/inc/template-tags.php',
	'/inc/template-functions.php',
	'/inc/customizer.php',
	'/inc/widgets/add-sidebars.php',
	'/inc/dynamic-styles.php',
	'/inc/config/class-tgm-plugin-activation.php',
	'/inc/config/plugins.config.php',
	'/inc/config/importer.config.php',
);

foreach ($file_paths as $file_path) {
	require get_parent_theme_file_path() . $file_path;
}

if(function_exists('cs_framework_init')){
	require get_template_directory() . '/inc/config/theme-options.php';
	require get_template_directory() . '/inc/config/metabox-options.php';
}


/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}



