<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // exit if accessed directly
}

/**
 * Create the settings page
 */
add_filter( 'cs_framework_settings', 'yeti_settings_page' );
function yeti_settings_page( $settings ) {
    $settings = array(
        'menu_title' => esc_html__( 'Yeti Options', 'yeti' ),
        'menu_type' => 'submenu',
        'menu_parent' => 'themes.php',
        'menu_slug' => 'yeti-options',
        'framework_title' => esc_html__( 'Yeti Options', 'yeti' ),
        'show_reset_all' => true,
        'ajax_save' => false
    );

    return $settings;
}

/**
 * Pass the options for settings page
 */
add_filter( 'cs_framework_options', 'yeti_settings_page_options' );
function yeti_settings_page_options( $options ) {

  /* Get Preloader Lists */
  $preloaderpath = YETI_IMAGES.'preloader/';
  $preloaders = array(
    'loader2' => $preloaderpath . 'loader2.gif',  
    'loader4' => $preloaderpath . 'loader4.gif', 
    'loader5' => $preloaderpath . 'loader5.gif', 
    'loader6' => $preloaderpath . 'loader6.gif', 
    'loader7' => $preloaderpath . 'loader7.gif', 
    'loader9' => $preloaderpath . 'loader9.gif',
    'loader11' => $preloaderpath . 'loader11.gif',
    'loader12' => $preloaderpath . 'loader12.gif',
    'loader13' => $preloaderpath . 'loader13.gif',
    'loader14' => $preloaderpath . 'loader14.gif',
    'loader16' => $preloaderpath . 'loader16.gif',
    'loader17' => $preloaderpath . 'loader17.gif',
    'loader18' => $preloaderpath . 'loader18.gif',
    'loader19' => $preloaderpath . 'loader19.gif'

    );

    $options = array();
    /**
     * General Settings
     */

    $options[] = array(
        'name' => 'general',
        'title' => esc_html__( 'General Settings', 'yeti' ),
        'icon' => 'fa fa-cog',
        'fields' => array(


            // color options
            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Theme Color Scheme', 'yeti' ),
            ),

            array(
                'type'    => 'color_picker',
                'id'      => 'primary_color',
                'title'   => esc_html__( 'Primary Color', 'yeti' ),
                'default' => '#ff8b24'
            ),

            array(
                'type'    => 'color_picker',
                'id'      => 'secondary_color',
                'title'   => esc_html__( 'Secondary Color', 'yeti' ),
                'default' => '#5029c0'
            ),

            // other settings
            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Logo Options', 'yeti' ),
            ),

            array(
                'id' => 'default-logo',
                'type' => 'image',
                'title' => esc_html__( 'Default Logo', 'yeti' ),
                'desc' => esc_html__( 'Non retina version', 'yeti' ),
            ),

            array(
                'id' => 'retina-logo',
                'type' => 'image',
                'title' => esc_html__( 'Retina Logo', 'yeti' ),
                'desc' => esc_html__( 'Retina version', 'yeti' ),
            ),

            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Other Settings', 'yeti' ),
            ),

            array(
                'id' => 'back-to-top',
                'type' => 'switcher',
                'title' => esc_html__( 'Back to Top', 'yeti' ),
                'desc' => esc_html__( 'Enable or disable to top', 'yeti' ),
                'default' => 1
            ),
            array(
                'id' => 'gutenberg_enable',
                'type' => 'switcher',
                'title' => esc_html__( 'Enable/Disable Gutenberg', 'yeti' ),
                'desc' => esc_html__( 'Enable or disable Gutenberg Editor from Post/Page Editor', 'yeti' ),
                'default' => 1
            ),
        )
    );

    /**
     * General Settings
     */

    $options[] = array(
        'name' => 'preloader',
        'title' => esc_html__( 'Preloader Settings', 'yeti' ),
        'icon' => 'fa fa-bolt',
        'fields' => array(


            // color options
            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Preloader Settings', 'yeti' ),
            ),

            array(
              'id'    => 'yeti_preloader_enable',
              'type'  => 'switcher',
              'title' => esc_html__('Enable Preloaders','yeti'),
              'default' => true,
              'help'  => esc_html__('Show or hide preloaders while loading your site','yeti'),
            ),
            array(
              'id'        => 'yeti_preloader_lists',
              'type'      => 'image_select',
              'title'     => esc_html__('Choose Preloaders','yeti'),
              'options'   => $preloaders,
              'default'   => 'loader1',
              'dependency' => array('yeti_preloader_enable','==','true'),
            ),
        )
    );

    /**
     * Header Options
     */
    $options[] = array(
        'name' => 'header',
        'title' => esc_html__( 'Header Settings', 'yeti' ),
        'icon' => 'fa fa-header',
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Header Layout', 'yeti' ),
            ),

            array(
                'id'  => 'header_layout',
                'type' => 'image_select',
                'title' => esc_html__( 'Choose Header Layout', 'yeti' ),
                'options' => array(
                    'layout1' => YETI_IMAGES . 'header-1.jpg',
                    'layout2' => YETI_IMAGES . 'header-2.jpg',
                ),
                'default' => 'layout1'
            ),

            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Extra Button', 'yeti' ),
                'dependency' => array('header_layout_layout1','==','true')
            ),
            array(
                'id' => 'header_extra_btn_text',
                'type' => 'text',
                'title' => esc_html__( 'Button Text', 'yeti' ),
                'dependency' => array('header_layout_layout1','==','true')
            ),
            array(
                'id' => 'header_extra_btn_url',
                'type' => 'text',
                'title' => esc_html__( 'Button URL', 'yeti' ),
                'dependency' => array('header_layout_layout1','==','true')
            ),
            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Side Menu Styling', 'yeti' ),
                'dependency' => array('header_layout_layout2','==','true')
            ),
            array(
                'type'    => 'color_picker',
                'id'      => 'menu_bg_color',
                'title'   => esc_html__( 'Background Color', 'yeti' ),
                'default' => '#202020',
                'dependency' => array('header_layout_layout2','==','true')
            ),

            array(
                'type'    => 'color_picker',
                'id'      => 'menu_text_color',
                'title'   => esc_html__( 'Text Color', 'yeti' ),
                'default' => '#fff',
                'dependency' => array('header_layout_layout2','==','true')
            ),

            array(
                'type'    => 'color_picker',
                'id'      => 'menu_text_hcolor',
                'title'   => esc_html__( 'Text Hover Color', 'yeti' ),
                'default' => '#fff',
                'dependency' => array('header_layout_layout2','==','true')
            ),


            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Sticky Header', 'yeti' ),
            ),

            array(
              'id'    => 'yeti_sticky_header',
              'type'  => 'switcher',
              'title' => esc_html__('Sticky Header','yeti'),
              'default' => true,
            ),  
        ),
    );

    /**
     * Typography Options
     */
    $options[] = array(
        'name' => 'typography',
        'title' => esc_html__( 'Typography Options', 'yeti' ),
        'icon' => 'fa fa-font',
        'fields' => array(
            
            array(
                'id'        => 'body-font',
                'type'      => 'typography_advanced',
                'title'     => esc_html__('Body Font', 'yeti'),
                'default'   => array(
                  'family'  => 'Libre Franklin',
                  'variant' => array( 'regular'),
                  'font'    => 'google',
                  'size'    => '15',
                  'color'   => '#202020'
                ),
                'height' => false,
                'chosen'    => true,
                'preview'   => true,
              ),

            array(
                'id' => 'heading-font',
                'type' => 'typography_advanced',
                'title' => esc_html__( 'Heading', 'yeti' ),
                'default' => array(
                    'family' => 'Poppins',
                    'variant' => array( 'regular','200', '300','300italic','italic'),
                    'font' => 'google',
                    'size'    => '20',
                    'color' => '#090909'
                ),
                'variant' => true,
                'chosen'    => true,
                'size'       => false,
                'preview'   => true,
            ),

            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Font size', 'yeti' ),
            ),

            array(
                'id' => 'h1-font-size',
                'type' => 'text',
                'after' => 'px',
                'title' => esc_html__( 'H1 font size','yeti' ),
                'default' => '40'
            ),

            array(
                'id' => 'h2-font-size',
                'type' => 'text',
                'after' => 'px',
                'title' => esc_html__( 'H2 font size', 'yeti' ),
                'default' => '36',
            ),

            array(
                'id' => 'h3-font-size',
                'type' => 'text',
                'after' => 'px',
                'title' => esc_html__( 'H3 font size', 'yeti' ),
                'default' => '32',
            ),

            array(
                'id' => 'h4-font-size',
                'type' => 'text',
                'after' => 'px',
                'title' => esc_html__( 'H4 font size', 'yeti' ),
                'default' => '24',
            ),

            array(
                'id' => 'h5-font-size',
                'type' => 'text',
                'after' => 'px',
                'title' => esc_html__( 'H5 font size', 'yeti' ),
                'default' => '20',
            ),

            array(
                'id' => 'h6-font-size',
                'type' => 'text',
                'after' => 'px',
                'title' => esc_html__( 'H6 font size', 'yeti' ),
                'default' => '18',
            ),
        )
    );
        
    /*Social Icon Options */
    $options[]      = array(
        'name'        => 'social_settings',
        'title'       => esc_html__('Social Settings','yeti'),
        'icon'        => 'fa fa-globe',
        'fields'      => array(
           array(
                'type'    => 'subheading',
                'content' => esc_html__('Social Icons','yeti'),
            ),
            array(
              'id'              => 'yeti_social_icons',
              'type'            => 'group',
              'title'           => esc_html__('Social Icons', 'yeti'),
              'button_title'    => esc_html__('Add New', 'yeti'),
              'accordion_title' => esc_html__('Add New Icon', 'yeti'),
              'fields'          => array(
                    array(
                      'id'          => 'yeti_social_title',
                      'type'        => 'text',
                      'title'       => esc_html__('Name', 'yeti'),
                    ),
                    array(
                      'id'          => 'yeti_social_link',
                      'type'        => 'text',
                      'title'       => esc_html__('Link', 'yeti'),
                    ),
                    array(
                      'id'          => 'yeti_social_icon',
                      'type'        => 'icon',
                      'title'       => esc_html__('Icon', 'yeti'),
                    ),
                ),
                'default'   => array(
                   array(
                      'yeti_social_title'  => esc_html__('facebook', 'yeti'),
                      'yeti_social_icon'  => 'fa fa-facebook',
                      'yeti_social_link'  => '#',
                    ),
                    array(
                      'yeti_social_title'  => esc_html__('twitter', 'yeti'),
                      'yeti_social_icon'  => 'fa fa-twitter',
                      'yeti_social_link'  => '#',
                    ),
                    array(
                      'yeti_social_title'  => esc_html__('linkedin', 'yeti'),
                      'yeti_social_icon'  => 'fa fa-linkedin',
                      'yeti_social_link'  => '#',
                    ),
                    array(
                      'yeti_social_title'  => esc_html__('dribbble', 'yeti'),
                      'yeti_social_icon'  => 'fa fa-dribbble',
                      'yeti_social_link'  => '#',
                    )
                )
            ),                                    
        ),
    );

    /**
     * Page Options
     */
    $options[] = array(
        'name' => 'page',
        'title' => esc_html__( 'Page Settings', 'yeti' ),
        'icon' => 'fa fa-file',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Default Page Settings', 'yeti' ),
            ),

            array(
                'id' => 'page_banner_image',
                'type' => 'upload',
                'title' => esc_html__( 'Banner Image', 'yeti' ),
            ), 
            array(
                'id' => 'page_banner_bg_color',
                'type' => 'color_picker',
                'title' => esc_html__( 'Background Color', 'yeti' ),
                'default' => '#202020',
            ),
            array(
                'id' => 'page_banner_height',
                'type' => 'number',
                'title' => esc_html__( 'Banner Height', 'yeti' ),
                'default' => 200,
                'after' => 'px',
            ), 
        ),
    );
    /**
     * Portfolio Options
     */
    $options[] = array(
        'name' => 'portfolio',
        'title' => esc_html__( 'Portfolio Settings', 'yeti' ),
        'icon' => 'fa fa-folder',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Portfolio Settings', 'yeti' ),
            ),
            array(
                'id'             => 'portfolio_layout',
                'type'           => 'select',
                'title'          => esc_html__( 'Choose Portfolio Layout', 'yeti' ),
                'options'        => array(
                    'layout1'          => esc_html__( 'Masonry', 'yeti' ),
                    'layout2'     => esc_html__( 'Two Column', 'yeti' ),
                    'layout3'     => esc_html__( 'Three Column', 'yeti' ),
                ),
                'default' => 'layout2',
            ),
            array(
                'id' => 'portfolio_banner',
                'type' => 'upload',
                'title' => esc_html__( 'Banner Image', 'yeti' ),
            ),
            array(
                'id' => 'portfolio_banner_bg_color',
                'type' => 'color_picker',
                'title' => esc_html__( 'Background Color', 'yeti' ),
                'default' => '#202020',
            ),
            array(
                'id' => 'portfolio_banner_height',
                'type' => 'number',
                'title' => esc_html__( 'Banner Height', 'yeti' ),
                'default' => 200,
                'after' => 'px'
            ), 
            array(
                'id' => 'portfolio_title',
                'type' => 'text',
                'title' => esc_html__( 'Banner Title', 'yeti' ),
            ),
        )
    );                  
    /**
     * Blog Options
     */
    $options[] = array(
        'name' => 'blog',
        'title' => esc_html__( 'Blog Settings', 'yeti' ),
        'icon' => 'fa fa-folder',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Blog Page Settings', 'yeti' ),
            ),
            array(
              'id'      => 'blog_header_transparent',
              'type'    => 'checkbox',
              'title'   => esc_html__( 'Transparent Header ?', 'yeti' ),
            ),
            array(
                'id'             => 'blog_layout',
                'type'           => 'select',
                'title'          => esc_html__( 'Choose Blog Layout', 'yeti' ),
                'options'        => array(
                    'grid'          => esc_html__( 'Grid', 'yeti' ),
                    'list'     => esc_html__( 'List', 'yeti' ),
                ),
                'default' => 'list',
            ),
            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Sidebar Settings', 'yeti' ),
            ),
            array(
                'id'             => 'blog_sidebar_layout',
                'type'           => 'select',
                'title'          => esc_html__( 'Choose Sidebar Layout', 'yeti' ),
                'options'        => array(
                    'nosidebar'          => esc_html__( 'No Sidebar', 'yeti' ),
                    'leftsidebar'     => esc_html__( 'Left Sidebar', 'yeti' ),
                    'rightsidebar'     => esc_html__( 'Right Sidebar', 'yeti' ),
                ),
                'default' => 'rightsidebar'
            ),
            array(
                'id' => 'blog_sidebar',
                'type' => 'select',
                'options' => 'sidebar',
                'title' => esc_html__( 'Choose sidebar', 'yeti' ),
                'default_option' => esc_html__( 'Select Sidebar', 'yeti' ),
                'default' => 'default-sidebar',
                'dependency' => array('blog_sidebar_layout','!=','nosidebar'),
            ),
            array(
                'id' => 'blog_banner',
                'type' => 'upload',
                'title' => esc_html__( 'Banner Image', 'yeti' ),
                'dependency' => array('blog_layout','==','list'),
            ), 
            array(
                'id' => 'blog_banner_bg_color',
                'type' => 'color_picker',
                'title' => esc_html__( 'Background Color', 'yeti' ),
                'default' => '#202020',
                'dependency' => array('blog_layout','==','list'),
            ),
            array(
                'id' => 'blog_banner_height',
                'type' => 'number',
                'title' => esc_html__( 'Banner Height', 'yeti' ),
                'default' => 200,
                'after' => 'px',
                'dependency' => array('blog_layout','==','list'),
            ), 
            array(
                'id' => 'blog_title',
                'type' => 'text',
                'title' => esc_html__( 'Title', 'yeti' ),
            ),
            array(
                'id' => 'blog_desc',
                'type' => 'textarea',
                'title' => esc_html__( 'Sub Title', 'yeti' ),
            ),            
            array(
                'id' => 'blog_excerpt',
                'type' => 'number',
                'title' => esc_html__( 'Excerpt Length', 'yeti' ),
                'default' => 50,
            ),
            array(
                'id' => 'read_more_text',
                'type' => 'text',
                'title' => esc_html__( 'Read More Text', 'yeti' ),
                'default' => esc_html__( 'Read Full Story', 'yeti' ),
            ),

            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Single Post Settings', 'yeti' ),
            ),
            array(
                'id'             => 'single_post_layout',
                'type'           => 'select',
                'title'          => esc_html__( 'Choose Post Layout', 'yeti' ),
                'options'        => array(
                    'full'          => esc_html__( 'Fullwidth', 'yeti' ),
                    '2col'     => esc_html__( 'Two Column', 'yeti' ),
                ),
                'default' => 'full',
            ),
            array(
                'id' => 'blog_single_sidebar_layout',
                'type' => 'select',
                'title' => esc_html__( 'Sidebar position', 'yeti' ),
                'default' => 'rightsidebar',
                'desc' => esc_html__( 'Sidebar position for blog single page', 'yeti' ),
                'options' => array(
                    'leftsidebar'     => esc_html__( 'Left Sidebar', 'yeti' ),
                    'rightsidebar'     => esc_html__( 'Right Sidebar', 'yeti' ),
                ),
                'dependency' => array('single_post_layout','==','2col'),
            ),
            array(
                'id' => 'blog_single_sidebar',
                'type' => 'select',
                'options' => 'sidebar',
                'title' => esc_html__( 'Choose sidebar', 'yeti' ),
                'default_option' => esc_html__( 'Select Sidebar', 'yeti' ),
                'default' => 'default-sidebar',
                'dependency' => array('single_post_layout','==','2col'),
            ),
            array(
                'type' => 'subheading',
                'content' => esc_html__( 'CTA Settings', 'yeti' ),
            ),
            array(
                'id' => 'cta_content',
                'type' => 'wysiwyg',
                'title' => esc_html__( 'CTA Content', 'yeti' ),
            ), 

        ),
    );

    /**
     * Footer Options
     */
    $options[] = array(
        'name' => 'footer',
        'title' => esc_html__( 'Footer Settings', 'yeti' ),
        'icon' => 'fa fa-building',
        'fields' => array(
            array(
                'type' => 'heading',
                'content' => esc_html__( 'Footer Settings', 'yeti' ),
            ),
            array(
                'id'  => 'footer_layout',
                'type' => 'image_select',
                'title' => esc_html__( 'Choose Footer Layout', 'yeti' ),
                'options' => array(
                    'layout1' => YETI_IMAGES . 'footer-1.jpg',
                    'layout2' => YETI_IMAGES . 'footer-2.jpg',
                    'layout3' => YETI_IMAGES . 'footer-3.png',
                ),
                'default' => 'layout3'
            ),
            array(
                'id' => 'footer_logo',
                'type' => 'image',
                'title' => esc_html__( 'Footer Logo', 'yeti' ),
                'dependency' => array('footer_layout_layout3','!=','true')
            ),
            array(
                'id' => 'footer_social_enable',
                'type' => 'switcher',
                'title' => esc_html__( 'Enable or Disable Social Icons', 'yeti' ),
                'default' => 1,
                'dependency' => array('footer_layout_layout3','!=','true')
            ),
            array(
                'id' => 'footer_email',
                'type' => 'text',
                'title' => esc_html__( 'Email Address', 'yeti' ),
                'dependency' => array('footer_layout_layout3','!=','true')
            ),
            array(
                'id' => 'footer_phone',
                'type' => 'text',
                'title' => esc_html__( 'Phone Number', 'yeti' ),
                'dependency' => array('footer_layout_layout3','!=','true')
            ),
            array(
                'id' => 'footer_address',
                'type' => 'textarea',
                'title' => esc_html__( 'Contact Address', 'yeti' ),
                'dependency' => array('footer_layout_layout3','!=','true')
            ),
            array(
              'type'    => 'notice',
              'class'   => 'info',
              'content' => esc_html__( 'Please Go to your Dashboard > Appearance > Widgets and add widgets to footer widget area', 'yeti' ),
              'dependency' => array('footer_layout_layout3','==','true')
            ),
            array(
                'type' => 'subheading',
                'content' => esc_html__( 'Bottom Footer', 'yeti' ),
            ),
            array(
                'id' => 'footer_copyright',
                'type' => 'textarea',
                'title' => esc_html__( 'Copyright Text', 'yeti' ),
                'desc'  =>  wp_kses_post( esc_html__( 'Enter your copyright notice. Shortcode can be used here. Available Shortcodes: [year], [site_name]', 'yeti' ) ),
                'default'   =>  esc_html__( '&copy; [year] [site_name]. All rights reserved', 'yeti')
            ),
            array(
                'id' => 'google_analytics',
                'type' => 'textarea',
                'title' => esc_html__( 'Google Analytics', 'yeti' ),
                'before'    =>  esc_html__( 'Do not use &lt;script&gt; &lt;/script&gt; tag, it will be added by default', 'yeti' ),
                'desc' => esc_html__( 'Place your google analytics code here', 'yeti' ),
            ),

        ),
    ); 

    /**
     * Custom CSS & JS
     */

    $options[] = array(
        'name'      =>      'css_js',
        'title'     =>      esc_html__( 'Custom CSS & JS', 'yeti' ),
        'icon'      =>      'fa fa-code',
        'fields'        =>      array(
            array(
                'id'      => 'css',
                'type'    => 'textarea',
                'title'   => esc_html__( 'Custom CSS', 'yeti' ),
                'desc'  =>  esc_html__( 'All the custom css will be placed within &lt;head&gt; &lt;/head&gt; tag', 'yeti' ),
                'before'    =>  esc_html__( 'Do not use &lt;style&gt; &lt;/style&gt; tag, it will be added by default', 'yeti' ),
                'attributes'    =>  array(
                    'rows'  =>  12,
                )
            ),

            array(
                'id'      => 'js',
                'type'    => 'textarea',
                'title'   => esc_html__( 'Custom JS', 'yeti' ),
                'desc'  =>  esc_html__( 'All the custom js will be placed before closing &lt;/body&gt; tag.', 'yeti' ),
                'before'    =>  esc_html__( 'Do not use &lt;script&gt; &lt;/script&gt; tag, it will be added by default', 'yeti' ),
                'attributes'    =>  array(
                    'rows'  =>  12,
                )
            ),
        )
    );


    /**
     * Backup Options
     */
    $options[]   = array(
        'name'     =>       'backup_restore',
        'title'    =>       esc_html__( 'Backup & restore', 'yeti' ),
        'icon'     =>       'fa fa-refresh',
        'fields'   =>       array(

            array(
            'type'    =>    'notice',
            'class'   =>    'warning',
            'content' =>    esc_html__( 'You can save your current options. Download a Backup and Import.', 'yeti' ),
            ),
            array(
            'type'    => 'backup',
            ),

        )
    );

    return $options;
}