<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package yeti
 */

get_header();
$meta = get_post_meta(get_the_ID(),'_custom_meta',true); 
$blog_title = cs_get_option('blog_title','Blog');
if($blog_title == ''){
	$blog_title = get_the_title( get_option('page_for_posts', true) );
}

$blog_desc = cs_get_option('blog_desc');
$blog_banner = cs_get_option('blog_banner');  
$archive_layout = cs_get_option('blog_layout','list');

?>
<!-- Banner starts -->
<?php if($archive_layout == 'list'){?>
<section class="banner-wrapper inner blog">
	<figure class="service-parallax parallax parallax-window12" data-parallax="scroll" data-image-src="<?php echo esc_url($blog_banner);?>">
        <span class="overlay"></span>         
    </figure>
	<div class="banner-content journal text-center font1">
		<div class="container">
            <div class="row">
                <div class="col-md-10 col-md-offset-1 col-sm-12 col-xs-12">
                    <h1>
                    <span><?php echo esc_html($blog_desc);?></span>
                    <?php echo wp_kses_post($blog_title);?>
                    </h1>
                </div>
            </div>
		</div>
	</div>
</section>
<?php } else{?>
<section class="intro-text-wrapper case bg16">
    <div class="intro-text">
        <div class="container">
            <div class="row">
                <div class="col-md-8 col-sm-10 col-xs-12">
                    <h1><?php echo esc_html($blog_title);?></h1>
                    <div class="dis-title">
                        <p><?php echo wp_kses_post($blog_desc);?></p>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>
<?php }?>
<!-- Banner Ends -->
<?php 
$sidebar = cs_get_option('blog_sidebar_layout','rightsidebar');
$sidebar_content = cs_get_option('blog_sidebar','default-sidebar');
if(!is_active_sidebar($sidebar_content)){
	$sidebar = 'nosidebar';
}
if($sidebar == 'nosidebar'){
	$c_class = 'col-xs-12 col-sm-12 col-md-12';
}else{
	$c_class = 'col-xs-12 col-sm-7 col-md-8';
}
if($archive_layout == 'list'){?>
<section id="down-arrow" class="case-study-single-wrapper v1 journal section-padding">
<?php }else{?>
<section class="journal-block-wrapper section-padding">
<?php }?>
    <div class="container <?php echo esc_attr($sidebar);?>">
        <div class="row">
            <div class="<?php echo esc_attr($c_class);?>">
				<?php
				if ( have_posts() ) :
                    echo '<div class="row">';
					/* Start the Loop */
					while ( have_posts() ) :
						the_post();

						/*
						 * Include the Post-Type-specific template for the content.
						 * If you want to override this in a child theme, then include a file
						 * called content-___.php (where ___ is the Post Type name) and that will be used instead.
						 */
						get_template_part( 'template-parts/archive/archive', $archive_layout );

					endwhile;
                    echo '</div>';
					the_posts_pagination( array(
	                  'prev_text' => '<i class="fa fa-chevron-left"></i>',
	                  'next_text'  => '<i class="fa fa-chevron-right"></i>',
					) );
                    
				else :

					get_template_part( 'template-parts/content', 'none' );

				endif;
				?> 
			</div>	
			<?php if($sidebar != 'nosidebar'){?>
			<div class="col-xs-12 col-sm-5 col-md-4 side-bar">
                <?php get_sidebar();?>
			</div>
			<?php }?>
		</div>
	</div>
</section>			


<?php
get_footer();
